@@ -21,7 +21,7 @@ from typing import (
 
 import pandas as pd
 
-from . import check_utils, constants, errors
+from . import check_utils, errors
 from . import strategies as st
 
 CheckResult = namedtuple(
@@ -29,7 +29,6 @@ CheckResult = namedtuple(
     ["check_output", "check_passed", "checked_object", "failure_cases"],
 )
 
-
 GroupbyObject = Union[
     pd.core.groupby.SeriesGroupBy, pd.core.groupby.DataFrameGroupBy
 ]
@@ -71,7 +70,7 @@ class _CheckMeta(type):  # pragma: no cover
 
     def __getattr__(cls, name: str) -> Any:
         """Prevent attribute errors for registered checks."""
-        attr = ChainMap(cls.__dict__, cls.REGISTERED_CUSTOM_CHECKS).get(name)
+        attr = ChainMap(cls.__dict__, cls.REGISTERED_CUSTOM_CHECKS).get(name)  # type: ignore
         if attr is None:
             raise AttributeError(
                 f"'{cls}' object has no attribute '{name}'. "
@@ -115,7 +114,9 @@ class _CheckBase(metaclass=_CheckMeta):
         name: str = None,
         error: Optional[str] = None,
         raise_warning: bool = False,
-        n_failure_cases: Union[int, None] = constants.N_FAILURE_CASES,
+        n_failure_cases: Optional[int] = None,
+        title: Optional[str] = None,
+        description: Optional[str] = None,
         **check_kwargs,
     ) -> None:
         """Apply a validation function to each element, Series, or DataFrame.
@@ -173,6 +174,8 @@ class _CheckBase(metaclass=_CheckMeta):
             check is informational and shouldn't stop execution of the program.
         :param n_failure_cases: report the first n unique failure cases. If
             None, report all failure cases.
+        :param title: A human-readable label for the check.
+        :param description: An arbitrary textual description of the check.
         :param check_kwargs: key-word arguments to pass into ``check_fn``
 
         :example:
@@ -187,6 +190,13 @@ class _CheckBase(metaclass=_CheckMeta):
         >>> # define an element-wise check
         >>> check_even = pa.Check(lambda x: x % 2 == 0, element_wise=True)
         >>>
+        >>> # checks can be given human-readable metadata
+        >>> check_with_metadata = pa.Check(
+        ...     lambda x: True,
+        ...     title="Always passes",
+        ...     description="This check always passes."
+        ... )
+        >>>
         >>> # specify assertions across categorical variables using `groupby`,
         >>> # for example, make sure the mean measure for group "A" is always
         >>> # larger than the mean measure for group "B"
@@ -241,6 +251,8 @@ class _CheckBase(metaclass=_CheckMeta):
         self.ignore_na = ignore_na
         self.raise_warning = raise_warning
         self.n_failure_cases = n_failure_cases
+        self.title = title
+        self.description = description
 
         if groupby is None and groups is not None:
             raise ValueError(
@@ -272,7 +284,7 @@ class _CheckBase(metaclass=_CheckMeta):
     def _format_groupby_input(
         groupby_obj: GroupbyObject,
         groups: Optional[List[str]],
-    ) -> Union[Dict[str, Union[pd.Series, pd.DataFrame]]]:
+    ) -> Dict[str, Union[pd.Series, pd.DataFrame]]:
         """Format groupby object into dict of groups to Series or DataFrame.
 
         :param groupby_obj: a pandas groupby object.
@@ -495,6 +507,17 @@ class _CheckBase(metaclass=_CheckMeta):
         )
 
 
+def _check_kwargs(
+    kwargs: Dict[str, Any],
+    default_name: str,
+    default_error: str,
+) -> Dict[str, Any]:
+    """Replace built-in check kwargs with customized name and error."""
+    kwargs["name"] = kwargs.get("name", default_name)
+    kwargs["error"] = kwargs.get("error", default_error)
+    return kwargs
+
+
 class Check(_CheckBase):
     """Check a pandas Series or DataFrame for certain properties."""
 
@@ -520,9 +543,9 @@ class Check(_CheckBase):
 
         return cls(
             _equal,
-            name=cls.equal_to.__name__,
-            error=f"equal_to({value})",
-            **kwargs,
+            **_check_kwargs(
+                kwargs, cls.equal_to.__name__, f"equal_to({value})"
+            ),
         )
 
     eq = equal_to
@@ -549,9 +572,9 @@ class Check(_CheckBase):
 
         return cls(
             _not_equal,
-            name=cls.not_equal_to.__name__,
-            error=f"not_equal_to({value})",
-            **kwargs,
+            **_check_kwargs(
+                kwargs, cls.not_equal_to.__name__, f"not_equal_to({value})"
+            ),
         )
 
     ne = not_equal_to
@@ -581,9 +604,11 @@ class Check(_CheckBase):
 
         return cls(
             _greater_than,
-            name=cls.greater_than.__name__,
-            error=f"greater_than({min_value})",
-            **kwargs,
+            **_check_kwargs(
+                kwargs,
+                cls.greater_than.__name__,
+                f"greater_than({min_value})",
+            ),
         )
 
     gt = greater_than
@@ -613,9 +638,11 @@ class Check(_CheckBase):
 
         return cls(
             _greater_or_equal,
-            name=cls.greater_than_or_equal_to.__name__,
-            error=f"greater_than_or_equal_to({min_value})",
-            **kwargs,
+            **_check_kwargs(
+                kwargs,
+                cls.greater_than_or_equal_to.__name__,
+                f"greater_than_or_equal_to({min_value})",
+            ),
         )
 
     ge = greater_than_or_equal_to
@@ -645,9 +672,11 @@ class Check(_CheckBase):
 
         return cls(
             _less_than,
-            name=cls.less_than.__name__,
-            error=f"less_than({max_value})",
-            **kwargs,
+            **_check_kwargs(
+                kwargs,
+                cls.less_than.__name__,
+                f"less_than({max_value})",
+            ),
         )
 
     lt = less_than
@@ -677,9 +706,11 @@ class Check(_CheckBase):
 
         return cls(
             _less_or_equal,
-            name=cls.less_than_or_equal_to.__name__,
-            error=f"less_than_or_equal_to({max_value})",
-            **kwargs,
+            **_check_kwargs(
+                kwargs,
+                cls.less_than_or_equal_to.__name__,
+                f"less_than_or_equal_to({max_value})",
+            ),
         )
 
     le = less_than_or_equal_to
@@ -732,9 +763,11 @@ class Check(_CheckBase):
 
         return cls(
             _in_range,
-            name=cls.in_range.__name__,
-            error=f"in_range({min_value}, {max_value})",
-            **kwargs,
+            **_check_kwargs(
+                kwargs,
+                cls.in_range.__name__,
+                f"in_range({min_value}, {max_value})",
+            ),
         )
 
     @classmethod
@@ -749,12 +782,16 @@ class Check(_CheckBase):
         :returns: :class:`Check` object
 
         .. note::
-            It is checked whether all elements of a :class:`pandas.Series`
+            This checks whether all elements of a :class:`pandas.Series`
             are part of the set of elements of allowed values. If allowed
             values is a string, the set of elements consists of all distinct
             characters of the string. Thus only single characters which occur
             in allowed_values at least once can meet this condition. If you
             want to check for substrings use :func:`Check.str_is_substring`.
+
+        .. note::
+            In constrast with :meth:`Check.unique_values_eq`, this check only makes
+            sure that the values in the checked data object are within an allowable set.
         """
         # Turn allowed_values into a set. Not only for performance but also
         # avoid issues with a mutable argument passed by reference which may be
@@ -772,9 +809,11 @@ class Check(_CheckBase):
 
         return cls(
             _isin,
-            name=cls.isin.__name__,
-            error=f"isin({set(allowed_values)})",
-            **kwargs,
+            **_check_kwargs(
+                kwargs,
+                cls.isin.__name__,
+                f"isin({set(allowed_values)})",
+            ),
         )
 
     @classmethod
@@ -812,9 +851,11 @@ class Check(_CheckBase):
 
         return cls(
             _notin,
-            name=cls.notin.__name__,
-            error=f"notin({set(forbidden_values)})",
-            **kwargs,
+            **_check_kwargs(
+                kwargs,
+                cls.notin.__name__,
+                f"notin({set(forbidden_values)})",
+            ),
         )
 
     @classmethod
@@ -846,9 +887,11 @@ class Check(_CheckBase):
 
         return cls(
             _match,
-            name=cls.str_matches.__name__,
-            error=f"str_matches({regex})",
-            **kwargs,
+            **_check_kwargs(
+                kwargs,
+                cls.str_matches.__name__,
+                f"str_matches({regex})",
+            ),
         )
 
     @classmethod
@@ -878,9 +921,11 @@ class Check(_CheckBase):
 
         return cls(
             _contains,
-            name=cls.str_contains.__name__,
-            error=f"str_contains({regex})",
-            **kwargs,
+            **_check_kwargs(
+                kwargs,
+                cls.str_contains.__name__,
+                f"str_contains({regex})",
+            ),
         )
 
     @classmethod
@@ -901,9 +946,11 @@ class Check(_CheckBase):
 
         return cls(
             _startswith,
-            name=cls.str_startswith.__name__,
-            error=f"str_startswith({string})",
-            **kwargs,
+            **_check_kwargs(
+                kwargs,
+                cls.str_startswith.__name__,
+                f"str_startswith({string})",
+            ),
         )
 
     @classmethod
@@ -924,9 +971,11 @@ class Check(_CheckBase):
 
         return cls(
             _endswith,
-            name=cls.str_endswith.__name__,
-            error=f"str_endswith({string})",
-            **kwargs,
+            **_check_kwargs(
+                kwargs,
+                cls.str_endswith.__name__,
+                f"str_endswith({string})",
+            ),
         )
 
     @classmethod
@@ -970,7 +1019,41 @@ class Check(_CheckBase):
 
         return cls(
             _str_length,
-            name=cls.str_length.__name__,
-            error=f"str_length({min_value}, {max_value})",
-            **kwargs,
+            **_check_kwargs(
+                kwargs,
+                cls.str_length.__name__,
+                f"str_length({min_value}, {max_value})",
+            ),
+        )
+
+    @classmethod
+    @register_check_statistics(["values"])
+    def unique_values_eq(
+        cls,
+        values: Iterable,
+        **kwargs,
+    ) -> "Check":
+        """Ensure that the unique values in the data object contain all specified values.
+
+        .. note::
+            In constrast with :meth:`Check.isin`, this check makes sure that all the items
+            in the ``values`` iterable are contained within the series.
+
+        :param values: The set of values that must be present. Maybe any iterable.
+        :param kwargs: key-word arguments passed into the `Check` initializer.
+        :returns: :class:`Check` object
+        """
+        set_values = frozenset(values)
+
+        def _unique_values_eq(series: pd.Series) -> pd.Series:
+            """Comparison function for check"""
+            return set(series.unique()) == set_values
+
+        return cls(
+            _unique_values_eq,
+            **_check_kwargs(
+                kwargs,
+                cls.unique_values_eq.__name__,
+                f"unique_values_eq({values})",
+            ),
         )
