@@ -3,6 +3,7 @@ import functools
 import inspect
 import sys
 import typing
+import types
 from collections import OrderedDict
 from typing import (
     Any,
@@ -20,6 +21,7 @@ from typing import (
 
 import pandas as pd
 import wrapt
+from pydantic import validate_arguments
 
 from . import errors, schemas
 from .inspection_utils import (
@@ -89,7 +91,10 @@ def _handle_schema_error(
     :raises SchemaError: when ``DataFrame`` violates built-in or custom
         checks.
     """
-    msg = f"error in {decorator_name} decorator of function '{fn.__name__}': {schema_error}"
+    func_name = fn.__name__
+    if isinstance(fn, types.MethodType):
+        func_name = fn.__self__.__class__.__name__ + "." + func_name
+    msg = f"error in {decorator_name} decorator of function '{func_name}': {schema_error}"
     raise errors.SchemaError(
         schema,
         arg_df,
@@ -97,7 +102,7 @@ def _handle_schema_error(
         failure_cases=schema_error.failure_cases,
         check=schema_error.check,
         check_index=schema_error.check_index,
-    )
+    ) from schema_error
 
 
 def check_input(
@@ -309,23 +314,49 @@ def check_output(
     See :ref:`here<decorators>` for more usage details.
     """
 
+    # make sure that callable obj_getter doesn't work when the schema has
+    # any component that requires coercion, since there's no way to re-assign
+    # the output to the coerced data.
+    # pylint: disable=too-many-boolean-expressions
+    if callable(obj_getter) and (
+        schema.coerce
+        or (schema.index is not None and schema.index.coerce)
+        or (
+            isinstance(schema, schemas.DataFrameSchema)
+            and any(col.coerce for col in schema.columns.values())
+        )
+    ):
+        raise ValueError(
+            "Cannot use callable obj_getter when the schema uses coercion."
+        )
+
     def validate(out: Any, fn: Callable) -> None:
+        def _try_validate(obj: Any):
+            try:
+                return schema.validate(
+                    obj, head, tail, sample, random_state, lazy, inplace
+                )
+            except errors.SchemaError as e:
+                _handle_schema_error("check_output", fn, schema, obj, e)
+
         if obj_getter is None:
-            obj = out
+            return _try_validate(out)
         elif isinstance(obj_getter, (int, str)):
             obj = out[obj_getter]
+            validated = _try_validate(obj)
+            if isinstance(out, tuple):
+                out = list(out)
+                out[obj_getter] = validated
+                out = tuple(out)
+            else:
+                out[obj_getter] = validated
+            return out
         elif callable(obj_getter):
             obj = obj_getter(out)
-        else:
-            raise TypeError(
-                f"obj_getter is unrecognized type: {type(obj_getter)}"
-            )
-        try:
-            schema.validate(
-                obj, head, tail, sample, random_state, lazy, inplace
-            )
-        except errors.SchemaError as e:
-            _handle_schema_error("check_output", fn, schema, obj, e)
+            _try_validate(obj)
+            return out
+
+        raise TypeError(f"obj_getter is unrecognized type: {type(obj_getter)}")
 
     @wrapt.decorator
     def _wrapper(
@@ -355,8 +386,7 @@ def check_output(
             return aio_wrapper()
         else:
             out = fn(*args, **kwargs)
-            validate(out, fn)
-            return out
+            return validate(out, fn)
 
     return _wrapper
 
@@ -457,6 +487,7 @@ def check_io(
 def check_types(
     wrapped: F,
     *,
+    with_pydantic: bool = False,
     head: Optional[int] = None,
     tail: Optional[int] = None,
     sample: Optional[int] = None,
@@ -471,6 +502,7 @@ def check_types(
 def check_types(
     wrapped: None = None,
     *,
+    with_pydantic: bool = False,
     head: Optional[int] = None,
     tail: Optional[int] = None,
     sample: Optional[int] = None,
@@ -484,6 +516,7 @@ def check_types(
 def check_types(
     wrapped=None,
     *,
+    with_pydantic: bool = False,
     head: Optional[int] = None,
     tail: Optional[int] = None,
     sample: Optional[int] = None,
@@ -495,6 +528,9 @@ def check_types(
 
     See the :ref:`User Guide <schema_models>` for more.
 
+    :param wrapped: the function to decorate.
+    :param with_pydantic: use ``pydantic.validate_arguments`` to validate
+        inputs. This function is still needed to validate function outputs.
     :param head: validate the first n rows. Rows overlapping with `tail` or
         `sample` are de-duplicated.
     :param tail: validate the last n rows. Rows overlapping with `head` or
@@ -512,6 +548,7 @@ def check_types(
     if wrapped is None:
         return functools.partial(
             check_types,
+            with_pydantic=with_pydantic,
             head=head,
             tail=tail,
             sample=sample,
@@ -521,41 +558,66 @@ def check_types(
         )
 
     # Front-load annotation parsing
-    annotated_schemas: Dict[str, Tuple[schemas.DataFrameSchema, bool]] = {}
+    annotated_schema_models: Dict[str, Tuple[SchemaModel, AnnotationInfo]] = {}
     for arg_name_, annotation in typing.get_type_hints(wrapped).items():
         annotation_info = AnnotationInfo(annotation)
         if not annotation_info.is_generic_df:
             continue
 
-        schema = cast(SchemaModel, annotation_info.arg).to_schema()
-        annotated_schemas[arg_name_] = (schema, annotation_info.optional)
+        schema_model = cast(SchemaModel, annotation_info.arg)
+        annotated_schema_models[arg_name_] = (schema_model, annotation_info)
 
     def _check_arg(arg_name: str, arg_value: Any) -> Any:
         """
         Validate function's argument if annoted with a schema, else
         pass-through.
         """
-        schema, optional = annotated_schemas.get(arg_name, (None, None))
+        schema_model, annotation_info = annotated_schema_models.get(
+            arg_name, (None, None)
+        )
+
+        if schema_model is None:
+            return arg_value
+
         if (
-            schema
-            and not (optional and arg_value is None)
+            annotation_info
+            and not (annotation_info.optional and arg_value is None)
             # the pandera.schema attribute should only be available when
             # schema.validate has been called in the DF. There's probably
             # a better way of doing this
-            and (
-                arg_value.pandera.schema is None
-                or arg_value.pandera.schema != schema
-            )
         ):
-            try:
-                return schema.validate(
-                    arg_value, head, tail, sample, random_state, lazy, inplace
-                )
-            except errors.SchemaError as e:
-                _handle_schema_error(
-                    "check_types", wrapped, schema, arg_value, e
-                )
-        return arg_value
+            config = schema_model.__config__
+            data_container_type = annotation_info.origin
+            schema = schema_model.to_schema()
+
+            if data_container_type and config and config.from_format:
+                arg_value = data_container_type.from_format(arg_value, config)
+
+            if (
+                arg_value.pandera.schema is None
+                # don't re-validate a dataframe that contains the same exact
+                # schema
+                or arg_value.pandera.schema != schema
+            ):
+                try:
+                    arg_value = schema.validate(
+                        arg_value,
+                        head,
+                        tail,
+                        sample,
+                        random_state,
+                        lazy,
+                        inplace,
+                    )
+                except errors.SchemaError as e:
+                    _handle_schema_error(
+                        "check_types", wrapped, schema, arg_value, e
+                    )
+
+            if data_container_type and config and config.to_format:
+                arg_value = data_container_type.to_format(arg_value, config)
+
+            return arg_value
 
     sig = inspect.signature(wrapped)
 
@@ -595,10 +657,13 @@ def check_types(
             args: Tuple[Any, ...],
             kwargs: Dict[str, Any],
         ):
-            validated_pos, validated_kwd = validate_inputs(
-                instance, args, kwargs
-            )
-            out = await wrapped_(*validated_pos.values(), **validated_kwd)
+            if with_pydantic:
+                out = await validate_arguments(wrapped_)(*args, **kwargs)
+            else:
+                validated_pos, validated_kwd = validate_inputs(
+                    instance, args, kwargs
+                )
+                out = await wrapped_(*validated_pos.values(), **validated_kwd)
             return _check_arg("return", out)
 
     else:
@@ -610,10 +675,13 @@ def check_types(
             args: Tuple[Any, ...],
             kwargs: Dict[str, Any],
         ):
-            validated_pos, validated_kwd = validate_inputs(
-                instance, args, kwargs
-            )
-            out = wrapped_(*validated_pos.values(), **validated_kwd)
+            if with_pydantic:
+                out = validate_arguments(wrapped_)(*args, **kwargs)
+            else:
+                validated_pos, validated_kwd = validate_inputs(
+                    instance, args, kwargs
+                )
+                out = wrapped_(*validated_pos.values(), **validated_kwd)
             return _check_arg("return", out)
 
     return _wrapper(wrapped)  # pylint:disable=no-value-for-parameter
