@@ -1,6 +1,9 @@
 """Pandera data types."""
 # pylint:disable=too-many-ancestors
+from __future__ import annotations
+
 import dataclasses
+import decimal
 import inspect
 from abc import ABC
 from typing import (
@@ -14,6 +17,11 @@ from typing import (
     Union,
 )
 
+try:
+    from typing import Literal
+except ImportError:
+    from typing_extensions import Literal  # type: ignore[misc]
+
 
 class DataType(ABC):
     """Base class of all Pandera data types."""
@@ -31,10 +39,13 @@ class DataType(ABC):
         """Coerce data container to the data type."""
         raise NotImplementedError()
 
+    def coerce_value(self, value: Any):
+        """Coerce an value to a particular type."""
+        raise NotImplementedError()
+
     def try_coerce(self, data_container: Any):
         """Coerce data container to the data type,
-        raises a `~pandera.errors.ParserError` if the coercion fails
-
+        raises a :class:`~pandera.errors.ParserError` if the coercion fails
         :raises: :class:`~pandera.errors.ParserError`: if coercion fails
         """
         raise NotImplementedError()
@@ -43,9 +54,20 @@ class DataType(ABC):
         """Coerce data container to the data type."""
         return self.coerce(data_container)
 
-    def check(self, pandera_dtype: "DataType") -> bool:
-        """Check that pandera :class:`~pandera.dtypes.DataType` are
-        equivalent."""
+    def check(
+        self,
+        pandera_dtype: "DataType",
+        data_container: Optional[Any] = None,  # pylint:disable=unused-argument
+    ) -> Union[bool, Iterable[bool]]:
+        """Check that pandera :class:`~pandera.dtypes.DataType` are equivalent.
+
+        :param pandera_dtype: Expected :class:`DataType`.
+        :param data_container: Data container, used by data types that require the
+            actual data for validation.
+
+        :returns: boolean scalar or iterable of boolean scalars, indicating which
+            elements passed the check.
+        """
         return self == pandera_dtype
 
     def __repr__(self) -> str:
@@ -110,7 +132,9 @@ class _Number(DataType):
     exact: Optional[bool] = None
     """Whether the data type is an exact representation of a number."""
 
-    def check(self, pandera_dtype: "DataType") -> bool:
+    def check(
+        self, pandera_dtype: "DataType", data_container: Optional[Any] = None
+    ) -> Union[bool, Iterable[bool]]:
         if self.__class__ is _Number:
             return isinstance(pandera_dtype, _Number)
         return super().check(pandera_dtype)
@@ -161,7 +185,9 @@ class Int(_PhysicalNumber):  # type: ignore
     signed: bool = dataclasses.field(default=True, init=False)
     """Whether the integer data type is signed."""
 
-    def check(self, pandera_dtype: DataType) -> bool:
+    def check(
+        self, pandera_dtype: "DataType", data_container: Optional[Any] = None
+    ) -> Union[bool, Iterable[bool]]:
         return (
             isinstance(pandera_dtype, Int)
             and self.signed == pandera_dtype.signed
@@ -266,7 +292,9 @@ class Float(_PhysicalNumber):  # type: ignore
     exact = False
     bit_width = 64
 
-    def check(self, pandera_dtype: DataType) -> bool:
+    def check(
+        self, pandera_dtype: "DataType", data_container: Optional[Any] = None
+    ) -> Union[bool, Iterable[bool]]:
         return (
             isinstance(pandera_dtype, Float)
             and self.bit_width == pandera_dtype.bit_width
@@ -318,7 +346,9 @@ class Complex(_PhysicalNumber):  # type: ignore
     _base_name = "complex"
     bit_width = 128
 
-    def check(self, pandera_dtype: DataType) -> bool:
+    def check(
+        self, pandera_dtype: "DataType", data_container: Optional[Any] = None
+    ) -> Union[bool, Iterable[bool]]:
         return (
             isinstance(pandera_dtype, Complex)
             and self.bit_width == pandera_dtype.bit_width
@@ -354,6 +384,70 @@ class Complex64(Complex128):
     bit_width = 64
 
 
+###############################################################################
+# decimal
+###############################################################################
+
+DEFAULT_PYTHON_PREC = 28
+
+
+def _scale_to_exp(scale: int) -> decimal.Decimal:
+    scale_fmt = format(10**-scale, f".{scale}f")
+    return decimal.Decimal(scale_fmt)
+
+
+@immutable(init=True)
+class Decimal(_Number):
+    """Semantic representation of a decimal data type."""
+
+    exact: bool = dataclasses.field(init=False, default=True)
+    continuous: bool = dataclasses.field(init=False, default=True)
+
+    precision: int = DEFAULT_PYTHON_PREC
+    """The number of significant digits that the decimal type can represent."""
+    scale: int = 0  # default 0 is aligned with pyarrow and various databases.
+    """The number of digits after the decimal point."""
+
+    # pylint: disable=line-too-long
+    rounding: str = dataclasses.field(
+        default_factory=lambda: decimal.getcontext().rounding
+    )
+    """
+    The `rounding mode <https://docs.python.org/3/library/decimal.html#rounding-modes>`__
+    supported by the Python :py:class:`decimal.Decimal` class.
+    """
+
+    def __init__(
+        self,
+        precision: int = DEFAULT_PYTHON_PREC,
+        scale: int = 0,
+        rounding: Optional[str] = None,
+    ):
+        super().__init__()
+        if precision <= 0:
+            raise ValueError(
+                f"Decimal precision {precision} must be positive."
+            )
+        if scale is not None and scale > precision:
+            raise ValueError(
+                f"Decimal scale {scale} must be between 0 and {precision}."
+            )
+        object.__setattr__(self, "precision", precision)
+        object.__setattr__(self, "scale", scale)
+        object.__setattr__(self, "rounding", rounding)
+        object.__setattr__(
+            self, "_exp", _scale_to_exp(scale) if scale else None
+        )
+        object.__setattr__(
+            self,
+            "_ctx",
+            decimal.Context(prec=precision, rounding=self.rounding),
+        )
+
+    def __str__(self) -> str:
+        return f"{self.__class__.__name__}({self.precision}, {self.scale})"
+
+
 ###############################################################################
 # nominal
 ###############################################################################
@@ -375,7 +469,9 @@ class Category(DataType):  # type: ignore
             object.__setattr__(self, "categories", tuple(categories))
         object.__setattr__(self, "ordered", ordered)
 
-    def check(self, pandera_dtype: "DataType") -> bool:
+    def check(
+        self, pandera_dtype: "DataType", data_container: Optional[Any] = None
+    ) -> Union[bool, Iterable[bool]]:
         if isinstance(pandera_dtype, Category) and (
             self.categories is None or pandera_dtype.categories is None
         ):
@@ -493,3 +589,13 @@ def is_datetime(pandera_dtype: Union[DataType, Type[DataType]]) -> bool:
 def is_timedelta(pandera_dtype: Union[DataType, Type[DataType]]) -> bool:
     """Return True if :class:`pandera.dtypes.DataType` is a timedelta."""
     return is_subdtype(pandera_dtype, Timedelta)
+
+
+UniqueSettings = Union[
+    # Report all unique errors except the first
+    Literal["exclude_first"],
+    # Report all unique errors except the last
+    Literal["exclude_last"],
+    # Report all unique errors
+    Literal["all"],
+]
