@@ -5,12 +5,11 @@ from typing import Union
 import pandas as pd
 
 from . import check_utils
-from .checks import _CheckBase
 
 
 def format_generic_error_message(
     parent_schema,
-    check: _CheckBase,
+    check,
     check_index: int,
 ) -> str:
     """Construct an error message when a check validator fails.
@@ -27,7 +26,7 @@ def format_generic_error_message(
 
 def format_vectorized_error_message(
     parent_schema,
-    check: _CheckBase,
+    check,
     check_index: int,
     reshaped_failure_cases: pd.DataFrame,
 ) -> str:
@@ -118,13 +117,8 @@ def reshape_failure_cases(
             .reset_index(drop=True)
         )
     elif check_utils.is_table(failure_cases):
-        reshaped_failure_cases = (
-            failure_cases.rename_axis("column", axis=1)
-            .rename_axis("index", axis=0)
-            .unstack()
-            .rename("failure_case")
-            .reset_index()
-        )
+        reshaped_failure_cases = failure_cases.unstack().reset_index()
+        reshaped_failure_cases.columns = ["column", "index", "failure_case"]
     elif check_utils.is_field(failure_cases):
         reshaped_failure_cases = failure_cases.rename("failure_case")
         reshaped_failure_cases.index.name = "index"
