@@ -134,28 +134,30 @@ class SchemaErrors(ReducedPickleExceptionBase):
     """Raised when multiple schema are lazily collected into one error."""
 
     TO_STRING_KEYS = [
+        "schema",
         "failure_cases",
         "data",
     ]
 
     def __init__(
         self,
+        schema,
         schema_errors: List[Dict[str, Any]],
         data: Union[pd.Series, pd.DataFrame],
     ):
         error_counts, failure_cases = self._parse_schema_errors(schema_errors)
+        self.schema = schema
         super().__init__(self._message(error_counts, failure_cases))
         self.schema_errors = schema_errors
         self.error_counts = error_counts
         self.failure_cases = failure_cases
         self.data = data
 
-    @staticmethod
-    def _message(error_counts, schema_errors):
+    def _message(self, error_counts, schema_errors):
         """Format error message."""
         msg = (
-            f"A total of {sum(error_counts.values())} "
-            "schema errors were found.\n"
+            f"Schema {self.schema.name}: A total of "
+            f"{sum(error_counts.values())} schema errors were found.\n"
         )
 
         msg += "\nError Counts"
@@ -254,18 +256,18 @@ class SchemaErrors(ReducedPickleExceptionBase):
                 )
                 check_failure_cases.append(failure_cases[column_order])
 
-        # NOTE: this is a hack to support koalas and modin
+        # NOTE: this is a hack to support pyspark.pandas and modin
         concat_fn = pd.concat
         if any(
-            type(x).__module__.startswith("databricks.koalas")
+            type(x).__module__.startswith("pyspark.pandas")
             for x in check_failure_cases
         ):
             # pylint: disable=import-outside-toplevel
-            import databricks.koalas as ks
+            import pyspark.pandas as ps
 
-            concat_fn = ks.concat
+            concat_fn = ps.concat
             check_failure_cases = [
-                x if isinstance(x, ks.DataFrame) else ks.DataFrame(x)
+                x if isinstance(x, ps.DataFrame) else ps.DataFrame(x)
                 for x in check_failure_cases
             ]
         elif any(
