@@ -1,13 +1,19 @@
 """Data validation checks for hypothesis testing."""
 
 from functools import partial
-from typing import Callable, Union, Optional, List, Dict
+from typing import Callable, Dict, List, Optional, Union
 
 import pandas as pd
-from scipy import stats
 
 from . import errors
-from .checks import _CheckBase, SeriesCheckObj, DataFrameCheckObj
+from .checks import DataFrameCheckObj, SeriesCheckObj, _CheckBase
+
+try:
+    from scipy import stats
+except ImportError:  # pragma: no cover
+    HAS_SCIPY = False
+else:
+    HAS_SCIPY = True
 
 
 DEFAULT_ALPHA = 0.01
@@ -18,26 +24,31 @@ class Hypothesis(_CheckBase):
 
     #: Relationships available for built-in hypothesis tests.
     RELATIONSHIPS = {
-        "greater_than": (lambda stat, pvalue, alpha=DEFAULT_ALPHA:
-                         stat > 0 and pvalue / 2 < alpha),
-        "less_than": (lambda stat, pvalue, alpha=DEFAULT_ALPHA:
-                      stat < 0 and pvalue / 2 < alpha),
-        "not_equal": (lambda stat, pvalue, alpha=DEFAULT_ALPHA:
-                      pvalue < alpha),
+        "greater_than": (
+            lambda stat, pvalue, alpha=DEFAULT_ALPHA: stat > 0
+            and pvalue / 2 < alpha
+        ),
+        "less_than": (
+            lambda stat, pvalue, alpha=DEFAULT_ALPHA: stat < 0
+            and pvalue / 2 < alpha
+        ),
+        "not_equal": (
+            lambda stat, pvalue, alpha=DEFAULT_ALPHA: pvalue < alpha
+        ),
         "equal": (lambda stat, pvalue, alpha=DEFAULT_ALPHA: pvalue >= alpha),
     }
 
     def __init__(
-            self,
-            test: Callable,
-            samples: Optional[Union[str, List[str]]] = None,
-            groupby: Optional[Union[str, List[str], Callable]] = None,
-            relationship: Union[str, Callable] = "equal",
-            test_kwargs: Dict = None,
-            relationship_kwargs: Dict = None,
-            name: Optional[str] = None,
-            error: Optional[str] = None,
-            raise_warning: bool = False,
+        self,
+        test: Callable,
+        samples: Optional[Union[str, List[str]]] = None,
+        groupby: Optional[Union[str, List[str], Callable]] = None,
+        relationship: Union[str, Callable] = "equal",
+        test_kwargs: Dict = None,
+        relationship_kwargs: Dict = None,
+        name: Optional[str] = None,
+        error: Optional[str] = None,
+        raise_warning: bool = False,
     ) -> None:
         """Perform a hypothesis test on a Series or DataFrame.
 
@@ -101,7 +112,7 @@ class Hypothesis(_CheckBase):
         >>> from scipy import stats
         >>>
         >>> schema = pa.DataFrameSchema({
-        ...     "height_in_feet": pa.Column(pa.Float, [
+        ...     "height_in_feet": pa.Column(float, [
         ...         pa.Hypothesis(
         ...             test=stats.ttest_ind,
         ...             samples=["A", "B"],
@@ -115,7 +126,7 @@ class Hypothesis(_CheckBase):
         ...             relationship_kwargs={"alpha": 0.05}
         ...         )
         ...     ]),
-        ...     "group": pa.Column(pa.String),
+        ...     "group": pa.Column(str),
         ... })
         >>> df = (
         ...     pd.DataFrame({
@@ -137,13 +148,14 @@ class Hypothesis(_CheckBase):
         self.test = partial(test, **{} if test_kwargs is None else test_kwargs)
         self.relationship = partial(
             self._relationships(relationship),
-            **{} if relationship_kwargs is None else relationship_kwargs)
+            **{} if relationship_kwargs is None else relationship_kwargs,
+        )
         if isinstance(samples, str):
             samples = [samples]
         elif samples is None:
             samples = []
         self.samples = samples
-        super(Hypothesis, self).__init__(
+        super().__init__(
             self._hypothesis_check,
             groupby=groupby,
             element_wise=False,
@@ -158,22 +170,23 @@ class Hypothesis(_CheckBase):
         return len(self.samples) <= 1
 
     def _prepare_series_input(
-            self,
-            series: pd.Series,
-            dataframe_context: pd.DataFrame = None
+        self,
+        df_or_series: Union[pd.Series, pd.DataFrame],
+        column: Optional[str] = None,
     ) -> SeriesCheckObj:
         """Prepare Series input for Hypothesis check."""
         self.groups = self.samples
-        return super(Hypothesis, self)._prepare_series_input(
-            series, dataframe_context)
+        return super()._prepare_series_input(df_or_series, column)
 
     def _prepare_dataframe_input(
-            self, dataframe: pd.DataFrame) -> DataFrameCheckObj:
+        self, dataframe: pd.DataFrame
+    ) -> DataFrameCheckObj:
         """Prepare input for DataFrameSchema Hypothesis check."""
         if self.groupby is not None:
             raise errors.SchemaDefinitionError(
                 "`groupby` cannot be used for DataFrameSchema checks, must "
-                "be used in Column checks.")
+                "be used in Column checks."
+            )
         if self.is_one_sample_test:
             return dataframe[self.samples[0]]
         check_obj = [(sample, dataframe[sample]) for sample in self.samples]
@@ -192,18 +205,18 @@ class Hypothesis(_CheckBase):
         if isinstance(relationship, str):
             if relationship not in self.RELATIONSHIPS:
                 raise errors.SchemaInitError(
-                    "The relationship %s isn't a built in method"
-                    % relationship)
+                    f"The relationship {relationship} isn't a built in method"
+                )
             relationship = self.RELATIONSHIPS[relationship]
         elif not callable(relationship):
             raise ValueError(
-                "expected relationship to be str or callable, found %s" % type(
-                    relationship)
+                "expected relationship to be str or callable, found "
+                f"{type(relationship)}"
             )
         return relationship
 
     def _hypothesis_check(
-            self, check_obj: Union[pd.Series, Dict[str, pd.Series]]
+        self, check_obj: Union[pd.Series, Dict[str, pd.Series]]
     ):
         """Create a function fn which is checked via the Check parent class.
 
@@ -214,19 +227,20 @@ class Hypothesis(_CheckBase):
         if isinstance(check_obj, pd.Series):
             return self.relationship(*self.test(check_obj))
         return self.relationship(
-            *self.test(*[check_obj.get(s) for s in self.samples]))
+            *self.test(*[check_obj.get(s) for s in self.samples])
+        )
 
     @classmethod
     def two_sample_ttest(
-            cls,
-            sample1: str,
-            sample2: str,
-            groupby: Union[str, List[str], Callable, None] = None,
-            relationship: str = "equal",
-            alpha=DEFAULT_ALPHA,
-            equal_var=True,
-            nan_policy="propagate",
-            raise_warning=False,
+        cls,
+        sample1: str,
+        sample2: str,
+        groupby: Union[str, List[str], Callable, None] = None,
+        relationship: str = "equal",
+        alpha=DEFAULT_ALPHA,
+        equal_var=True,
+        nan_policy="propagate",
+        raise_warning=False,
     ):
         """Calculate a t-test for the means of two samples.
 
@@ -285,7 +299,7 @@ class Hypothesis(_CheckBase):
         >>>
         >>> schema = pa.DataFrameSchema({
         ...     "height_in_feet": pa.Column(
-        ...         pa.Float, [
+        ...         float, [
         ...             pa.Hypothesis.two_sample_ttest(
         ...                 sample1="A",
         ...                 sample2="B",
@@ -294,7 +308,7 @@ class Hypothesis(_CheckBase):
         ...                 alpha=0.05,
         ...                 equal_var=True),
         ...     ]),
-        ...     "group": pa.Column(pa.String)
+        ...     "group": pa.Column(str)
         ... })
         >>> df = (
         ...     pd.DataFrame({
@@ -311,9 +325,18 @@ class Hypothesis(_CheckBase):
         4             4.0     B
 
         """
+        if not HAS_SCIPY:  # pragma: no cover
+            raise ImportError(
+                'Hypothesis checks requires "scipy" to be installed. \n'
+                "You can install pandera together with the Hypothesis "
+                "dependencies with: \n"
+                "pip install pandera[hypothesis]\n"
+            )
+
         if relationship not in cls.RELATIONSHIPS:
             raise errors.SchemaInitError(
-                "relationship must be one of %s" % set(cls.RELATIONSHIPS))
+                f"relationship must be one of {set(cls.RELATIONSHIPS)}"
+            )
         return cls(
             test=stats.ttest_ind,
             samples=[sample1, sample2],
@@ -322,20 +345,19 @@ class Hypothesis(_CheckBase):
             test_kwargs={"equal_var": equal_var, "nan_policy": nan_policy},
             relationship_kwargs={"alpha": alpha},
             name="two_sample_ttest",
-            error="failed two sample ttest between '%s' and '%s'" % (
-                sample1, sample2),
+            error=f"failed two sample ttest between '{sample1}' and '{sample2}'",
             raise_warning=raise_warning,
         )
 
     @classmethod
     def one_sample_ttest(
-            cls,
-            popmean: float,
-            sample: Optional[str] = None,
-            groupby: Union[str, List[str], Callable, None] = None,
-            relationship: str = "equal",
-            alpha: float = DEFAULT_ALPHA,
-            raise_warning=False,
+        cls,
+        popmean: float,
+        sample: Optional[str] = None,
+        groupby: Union[str, List[str], Callable, None] = None,
+        relationship: str = "equal",
+        alpha: float = DEFAULT_ALPHA,
+        raise_warning=False,
     ):
         """Calculate a t-test for the mean of one sample.
 
@@ -380,7 +402,7 @@ class Hypothesis(_CheckBase):
         >>>
         >>> schema = pa.DataFrameSchema({
         ...     "height_in_feet": pa.Column(
-        ...         pa.Float, [
+        ...         float, [
         ...             pa.Hypothesis.one_sample_ttest(
         ...                 popmean=5,
         ...                 relationship="greater_than",
@@ -402,9 +424,18 @@ class Hypothesis(_CheckBase):
 
 
         """
+        if not HAS_SCIPY:  # pragma: no cover
+            raise ImportError(
+                'Hypothesis checks requires "scipy" to be installed. \n'
+                "You can install pandera together with the hypothesis "
+                "dependencies with: \n"
+                "pip install pandera[hypothesis]"
+            )
+
         if relationship not in cls.RELATIONSHIPS:
             raise errors.SchemaInitError(
-                "relationship must be one of %s" % set(cls.RELATIONSHIPS))
+                f"relationship must be one of {set(cls.RELATIONSHIPS)}"
+            )
         return cls(
             test=stats.ttest_1samp,
             samples=sample,
@@ -413,6 +444,6 @@ class Hypothesis(_CheckBase):
             test_kwargs={"popmean": popmean},
             relationship_kwargs={"alpha": alpha},
             name="one_sample_ttest",
-            error="failed one sample ttest for column '%s'" % (sample),
+            error=f"failed one sample ttest for column '{sample}'",
             raise_warning=raise_warning,
         )
