@@ -1,5 +1,6 @@
 """Module for reading and writing schema objects."""
 
+import json
 import warnings
 from collections.abc import Mapping
 from functools import partial
@@ -33,8 +34,22 @@ except ImportError as exc:  # pragma: no cover
 DATETIME_FORMAT = "%Y-%m-%d %H:%M:%S"
 
 
-def _get_qualified_name(cls: type) -> str:
-    return f"{cls.__module__}.{cls.__qualname__}"
+def _get_dtype_string_alias(dtype: pandas_engine.DataType) -> str:
+    """Get string alias of the datatype for serialization.
+
+    Calling pandas_engine.Engine.dtype(<string_alias>) should be a valid
+    operation
+    """
+    str_alias = str(dtype)
+    try:
+        pandas_engine.Engine.dtype(str_alias)
+    except TypeError as e:  # pragma: no cover
+        raise TypeError(
+            f"string alias {str_alias} for datatype "
+            f"'{dtype.__module__}.{dtype.__class__.__name__}' not "
+            "recognized."
+        ) from e
+    return f'"{dtype}"'
 
 
 def _serialize_check_stats(check_stats, dtype=None):
@@ -100,7 +115,12 @@ def _serialize_component_stats(component_stats):
     if dtype:
         dtype = str(dtype)
 
+    description = component_stats.get("description")
+    title = component_stats.get("title")
+
     return {
+        "title": title,
+        "description": description,
         "dtype": dtype,
         "nullable": component_stats["nullable"],
         "checks": serialized_checks,
@@ -118,7 +138,7 @@ def _serialize_component_stats(component_stats):
     }
 
 
-def _serialize_schema(dataframe_schema):
+def serialize_schema(dataframe_schema):
     """Serialize dataframe schema into into json/yaml-compatible format."""
     from pandera import __version__  # pylint: disable=import-outside-toplevel
 
@@ -146,9 +166,16 @@ def _serialize_schema(dataframe_schema):
         "columns": columns,
         "checks": checks,
         "index": index,
+        "dtype": dataframe_schema.dtype,
         "coerce": dataframe_schema.coerce,
         "strict": dataframe_schema.strict,
+        "name": dataframe_schema.name,
+        "ordered": dataframe_schema.ordered,
         "unique": dataframe_schema.unique,
+        "report_duplicates": dataframe_schema._report_duplicates,
+        "unique_column_names": dataframe_schema.unique_column_names,
+        "title": dataframe_schema.title,
+        "description": dataframe_schema.description,
     }
 
 
@@ -180,6 +207,9 @@ def _deserialize_component_stats(serialized_component_stats):
     if dtype:
         dtype = pandas_engine.Engine.dtype(dtype)
 
+    description = serialized_component_stats.get("description")
+    title = serialized_component_stats.get("title")
+
     checks = serialized_component_stats.get("checks")
     if checks is not None:
         checks = [
@@ -189,6 +219,8 @@ def _deserialize_component_stats(serialized_component_stats):
             for check_name, check_stats in checks.items()
         ]
     return {
+        "title": title,
+        "description": description,
         "dtype": dtype,
         "checks": checks,
         **{
@@ -197,9 +229,6 @@ def _deserialize_component_stats(serialized_component_stats):
                 "name",
                 "nullable",
                 "unique",
-                # deserialize allow_duplicates property for backwards
-                # compatibility. Remove this for 0.8.0 release
-                "allow_duplicates",
                 "coerce",
                 "required",
                 "regex",
@@ -209,7 +238,14 @@ def _deserialize_component_stats(serialized_component_stats):
     }
 
 
-def _deserialize_schema(serialized_schema):
+def deserialize_schema(serialized_schema):
+    """
+    De-serialize the schema from a JSON-able mapping.
+
+    :param serialized_schema: a mapping representing the schema
+    :returns:
+        the schema de-serialized into :class:`~pandera.schemas.DataFrameSchema`
+    """
     # pylint: disable=import-outside-toplevel
     from pandera import Index, MultiIndex
 
@@ -256,9 +292,18 @@ def _deserialize_schema(serialized_schema):
         columns=columns,
         checks=checks,
         index=index,
+        dtype=serialized_schema.get("dtype", None),
         coerce=serialized_schema.get("coerce", False),
         strict=serialized_schema.get("strict", False),
+        name=serialized_schema.get("name", None),
+        ordered=serialized_schema.get("ordered", False),
         unique=serialized_schema.get("unique", None),
+        report_duplicates=serialized_schema.get("_report_duplicates", "all"),
+        unique_column_names=serialized_schema.get(
+            "unique_column_names", False
+        ),
+        title=serialized_schema.get("title", None),
+        description=serialized_schema.get("description", None),
     )
 
 
@@ -273,7 +318,7 @@ def from_yaml(yaml_schema):
             serialized_schema = yaml.safe_load(f)
     except (TypeError, OSError):
         serialized_schema = yaml.safe_load(yaml_schema)
-    return _deserialize_schema(serialized_schema)
+    return deserialize_schema(serialized_schema)
 
 
 def to_yaml(dataframe_schema, stream=None):
@@ -283,7 +328,7 @@ def to_yaml(dataframe_schema, stream=None):
     :param stream: file stream to write to. If None, dumps to string.
     :returns: yaml string if stream is None, otherwise returns None.
     """
-    statistics = _serialize_schema(dataframe_schema)
+    statistics = serialize_schema(dataframe_schema)
 
     def _write_yaml(obj, stream):
         return yaml.safe_dump(obj, stream=stream, sort_keys=False)
@@ -295,6 +340,57 @@ def to_yaml(dataframe_schema, stream=None):
         return _write_yaml(statistics, stream)
 
 
+def from_json(source):
+    """
+    Create :class:`~pandera.schemas.DataFrameSchema` from json file.
+
+    :param source:
+        Depending on the type, source is assumed to be:
+
+        1) str or Path to a file containing json schema (if the file exists),
+        2) str as a JSON-encoded schema, or
+        3) stream that we can read from containing the schema as JSON-encoded
+           string.
+
+    :returns: dataframe schema.
+    """
+    if isinstance(source, str):
+        try:
+            serialized_schema = json.loads(source)
+        except json.decoder.JSONDecodeError:
+            with Path(source).open(encoding="utf-8") as f:
+                serialized_schema = json.load(fp=f)
+    elif isinstance(source, Path):
+        with source.open(encoding="utf-8") as f:
+            serialized_schema = json.load(fp=f)
+    else:
+        serialized_schema = json.load(fp=source)
+
+    return deserialize_schema(serialized_schema)
+
+
+def to_json(dataframe_schema, target=None, **kwargs):
+    """
+    Write :class:`~pandera.schemas.DataFrameSchema` to json file.
+
+    :param dataframe_schema: schema to write to file or dump to string.
+    :param target: file path or stream to write to. If None, returns a
+        dump to string.
+    :param kwargs: keyword arguments to pass into :func:`json.dump`
+    :returns: json string if stream is None, otherwise returns None.
+    """
+    serialized_schema = serialize_schema(dataframe_schema)
+
+    if target is None:
+        return json.dumps(serialized_schema, sort_keys=False, **kwargs)
+
+    if isinstance(target, (str, Path)):
+        with Path(target).open("w", encoding="utf-8") as f:
+            json.dump(serialized_schema, fp=f, sort_keys=False, **kwargs)
+    else:
+        json.dump(serialized_schema, fp=target, sort_keys=False, **kwargs)
+
+
 SCRIPT_TEMPLATE = """
 from pandera import (
     DataFrameSchema, Column, Check, Index, MultiIndex
@@ -302,10 +398,18 @@ from pandera import (
 
 schema = DataFrameSchema(
     columns={{{columns}}},
+    checks={checks},
     index={index},
+    dtype={dtype},
     coerce={coerce},
     strict={strict},
     name={name},
+    ordered={ordered},
+    unique={unique},
+    report_duplicates={report_duplicates},
+    unique_column_names={unique_column_names},
+    title={title},
+    description={description},
 )
 """
 
@@ -318,13 +422,22 @@ Column(
     coerce={coerce},
     required={required},
     regex={regex},
+    description={description},
+    title={title},
 )
 """
 
-INDEX_TEMPLATE = (
-    "Index(dtype={dtype},checks={checks},"
-    "nullable={nullable},coerce={coerce},name={name})"
+INDEX_TEMPLATE = """
+Index(
+    dtype={dtype},
+    checks={checks},
+    nullable={nullable},
+    coerce={coerce},
+    name={name},
+    description={description},
+    title={title},
 )
+"""
 
 MULTIINDEX_TEMPLATE = """
 MultiIndex(indexes=[{indexes}])
@@ -354,8 +467,10 @@ def _format_index(index_statistics):
     index = []
     for properties in index_statistics:
         dtype = properties.get("dtype")
+        description = properties.get("description")
+        title = properties.get("title")
         index_code = INDEX_TEMPLATE.format(
-            dtype=f"{_get_qualified_name(dtype.__class__)}",
+            dtype=(None if dtype is None else _get_dtype_string_alias(dtype)),
             checks=(
                 "None"
                 if properties["checks"] is None
@@ -368,6 +483,8 @@ def _format_index(index_statistics):
                 if properties["name"] is None
                 else f"\"{properties['name']}\""
             ),
+            description=(None if description is None else f'"{description}"'),
+            title=(None if title is None else f'"{title}"'),
         )
         index.append(index_code.strip())
 
@@ -395,16 +512,18 @@ def to_script(dataframe_schema, path_or_buf=None):
     columns = {}
     for colname, properties in statistics["columns"].items():
         dtype = properties.get("dtype")
+        description = properties["description"]
+        title = properties["title"]
         column_code = COLUMN_TEMPLATE.format(
-            dtype=(
-                None if dtype is None else _get_qualified_name(dtype.__class__)
-            ),
+            dtype=(None if dtype is None else _get_dtype_string_alias(dtype)),
             checks=_format_checks(properties["checks"]),
             nullable=properties["nullable"],
             unique=properties["unique"],
             coerce=properties["coerce"],
             required=properties["required"],
             regex=properties["regex"],
+            description=(None if description is None else f'"{description}"'),
+            title=(None if title is None else f'"{title}"'),
         )
         columns[colname] = column_code.strip()
 
@@ -418,11 +537,18 @@ def to_script(dataframe_schema, path_or_buf=None):
 
     script = SCRIPT_TEMPLATE.format(
         columns=column_str,
+        checks=statistics["checks"],
         index=index,
+        dtype=dataframe_schema.dtype,
         coerce=dataframe_schema.coerce,
         strict=dataframe_schema.strict,
         name=dataframe_schema.name.__repr__(),
+        ordered=dataframe_schema.ordered,
         unique=dataframe_schema.unique,
+        report_duplicates=f'"{dataframe_schema._report_duplicates}"',
+        unique_column_names=dataframe_schema.unique_column_names,
+        title=dataframe_schema.title,
+        description=dataframe_schema.description,
     ).strip()
 
     # add pandas imports to handle datetime and timedelta.
@@ -679,4 +805,4 @@ def from_frictionless_schema(
             None if len(schema.primary_key) == 1 else list(schema.primary_key)
         ),
     }
-    return _deserialize_schema(assembled_schema)
+    return deserialize_schema(assembled_schema)
