@@ -1,4 +1,6 @@
 """Class-based api"""
+
+import copy
 import inspect
 import os
 import re
@@ -25,6 +27,7 @@ from . import schema_components
 from . import strategies as st
 from .checks import Check
 from .errors import SchemaInitError
+from .json_schema import to_json_schema
 from .model_components import (
     CHECK_KEY,
     DATAFRAME_CHECK_KEY,
@@ -36,6 +39,7 @@ from .model_components import (
 from .schemas import DataFrameSchema
 from .typing import INDEX_TYPES, SERIES_TYPES, AnnotationInfo
 from .typing.common import DataFrameBase
+from .typing.config import BaseConfig
 
 if sys.version_info[:2] < (3, 9):
     from typing_extensions import get_type_hints
@@ -56,6 +60,9 @@ _CONFIG_KEY = "Config"
 
 
 MODEL_CACHE: Dict[Type["SchemaModel"], DataFrameSchema] = {}
+GENERIC_SCHEMA_CACHE: Dict[
+    Tuple[Type["SchemaModel"], Tuple[Type[Any], ...]], Type["SchemaModel"]
+] = {}
 F = TypeVar("F", bound=Callable)
 TSchemaModel = TypeVar("TSchemaModel", bound="SchemaModel")
 
@@ -69,36 +76,6 @@ def docstring_substitution(*args: Any, **kwargs: Any) -> Callable[[F], F]:
     return decorator
 
 
-class BaseConfig:  # pylint:disable=R0903
-    """Define DataFrameSchema-wide options.
-
-    *new in 0.5.0*
-    """
-
-    name: Optional[str] = None  #: name of schema
-    coerce: bool = False  #: coerce types of all schema components
-
-    #: make sure certain column combinations are unique
-    unique: Optional[Union[str, List[str]]] = None
-
-    #: make sure all specified columns are in the validated dataframe -
-    #: if ``"filter"``, removes columns not specified in the schema
-    strict: Union[bool, str] = False
-
-    ordered: bool = False  #: validate columns order
-    multiindex_name: Optional[str] = None  #: name of multiindex
-
-    #: coerce types of all MultiIndex components
-    multiindex_coerce: bool = False
-
-    #: make sure all specified columns are in validated MultiIndex -
-    #: if ``"filter"``, removes indexes not specified in the schema
-    multiindex_strict: bool = False
-
-    #: validate MultiIndex in order
-    multiindex_ordered: bool = True
-
-
 def _is_field(name: str) -> bool:
     """Ignore private and reserved keywords."""
     return not name.startswith("_") and name != _CONFIG_KEY
@@ -166,6 +143,7 @@ class SchemaModel(metaclass=_MetaSchema):
     """
 
     Config: Type[BaseConfig] = BaseConfig
+    __extras__: Optional[Dict[str, Any]] = None
     __schema__: Optional[DataFrameSchema] = None
     __config__: Optional[Type[BaseConfig]] = None
 
@@ -182,6 +160,15 @@ class SchemaModel(metaclass=_MetaSchema):
 
     def __init_subclass__(cls, **kwargs):
         """Ensure :class:`~pandera.model_components.FieldInfo` instances."""
+        if "Config" in cls.__dict__:
+            cls.Config.name = (
+                cls.Config.name
+                if hasattr(cls.Config, "name")
+                else cls.__name__
+            )
+        else:
+            cls.Config = type("Config", (BaseConfig,), {"name": cls.__name__})
+
         super().__init_subclass__(**kwargs)
         # pylint:disable=no-member
         subclass_annotations = cls.__dict__.get("__annotations__", {})
@@ -192,13 +179,14 @@ class SchemaModel(metaclass=_MetaSchema):
                 field.__set_name__(cls, field_name)
                 setattr(cls, field_name, field)
 
+        cls.__config__, cls.__extras__ = cls._collect_config_and_extras()
+
     @classmethod
     def to_schema(cls) -> DataFrameSchema:
         """Create :class:`~pandera.DataFrameSchema` from the :class:`.SchemaModel`."""
         if cls in MODEL_CACHE:
             return MODEL_CACHE[cls]
 
-        cls.__config__, extras = cls._collect_config_and_extras()
         mi_kwargs = {
             name[len("multiindex_") :]: value
             for name, value in vars(cls.__config__).items()
@@ -206,6 +194,10 @@ class SchemaModel(metaclass=_MetaSchema):
         }
 
         cls.__fields__ = cls._collect_fields()
+        for field, (annot_info, _) in cls.__fields__.items():
+            if isinstance(annot_info.arg, TypeVar):
+                raise SchemaInitError(f"Field {field} has a generic data type")
+
         check_infos = typing.cast(
             List[FieldCheckInfo], cls._collect_check_infos(CHECK_KEY)
         )
@@ -216,21 +208,32 @@ class SchemaModel(metaclass=_MetaSchema):
 
         df_check_infos = cls._collect_check_infos(DATAFRAME_CHECK_KEY)
         df_custom_checks = cls._extract_df_checks(df_check_infos)
-        df_registered_checks = _convert_extras_to_checks(extras)
+        df_registered_checks = _convert_extras_to_checks(
+            {} if cls.__extras__ is None else cls.__extras__
+        )
         cls.__dataframe_checks__ = df_custom_checks + df_registered_checks
 
         columns, index = cls._build_columns_index(
             cls.__fields__, cls.__checks__, **mi_kwargs
         )
+        kwargs = {}
+        if cls.__config__ is not None:
+            kwargs = {
+                "dtype": cls.__config__.dtype,
+                "coerce": cls.__config__.coerce,
+                "strict": cls.__config__.strict,
+                "name": cls.__config__.name,
+                "ordered": cls.__config__.ordered,
+                "unique": cls.__config__.unique,
+                "title": cls.__config__.title,
+                "description": cls.__config__.description or cls.__doc__,
+                "unique_column_names": cls.__config__.unique_column_names,
+            }
         cls.__schema__ = DataFrameSchema(
             columns,
             index=index,
             checks=cls.__dataframe_checks__,  # type: ignore
-            coerce=cls.__config__.coerce,
-            strict=cls.__config__.strict,
-            name=cls.__config__.name,
-            ordered=cls.__config__.ordered,
-            unique=cls.__config__.unique,
+            **kwargs,  # type: ignore
         )
         if cls not in MODEL_CACHE:
             MODEL_CACHE[cls] = cls.__schema__  # type: ignore
@@ -266,9 +269,7 @@ class SchemaModel(metaclass=_MetaSchema):
     @classmethod
     @docstring_substitution(strategy_doc=DataFrameSchema.strategy.__doc__)
     @st.strategy_import_error
-    def strategy(
-        cls: Type[TSchemaModel], *, size: Optional[int] = None
-    ) -> DataFrameBase[TSchemaModel]:
+    def strategy(cls: Type[TSchemaModel], *, size: Optional[int] = None):
         """%(strategy_doc)s"""
         return cls.to_schema().strategy(size=size)
 
@@ -314,6 +315,8 @@ class SchemaModel(metaclass=_MetaSchema):
                     )
                 dtype_kwargs = _get_dtype_kwargs(annotation)
                 dtype = annotation.arg(**dtype_kwargs)  # type: ignore
+            elif annotation.default_dtype:
+                dtype = annotation.default_dtype
             else:
                 dtype = annotation.arg
 
@@ -377,7 +380,8 @@ class SchemaModel(metaclass=_MetaSchema):
         bases = inspect.getmro(cls)[:-1]  # bases -> SchemaModel -> object
         attrs = {}
         for base in reversed(bases):
-            attrs.update(base.__dict__)
+            if issubclass(base, SchemaModel):
+                attrs.update(base.__dict__)
         return attrs
 
     @classmethod
@@ -417,7 +421,7 @@ class SchemaModel(metaclass=_MetaSchema):
     ) -> Tuple[Type[BaseConfig], Dict[str, Any]]:
         """Collect config options from bases, splitting off unknown options."""
         bases = inspect.getmro(cls)[:-1]
-        bases = typing.cast(Tuple[Type[SchemaModel]], bases)
+        bases = tuple(base for base in bases if issubclass(base, SchemaModel))
         root_model, *models = reversed(bases)
 
         options, extras = _extract_config_options_and_extras(root_model.Config)
@@ -439,7 +443,7 @@ class SchemaModel(metaclass=_MetaSchema):
         walk the inheritance tree.
         """
         bases = inspect.getmro(cls)[:-2]  # bases -> SchemaModel -> object
-        bases = typing.cast(Tuple[Type[SchemaModel]], bases)
+        bases = tuple(base for base in bases if issubclass(base, SchemaModel))
 
         method_names = set()
         check_infos = []
@@ -512,6 +516,54 @@ class SchemaModel(metaclass=_MetaSchema):
 
         return cast("SchemaModel", schema_model)
 
+    @classmethod
+    def __modify_schema__(cls, field_schema):
+        """Update pydantic field schema."""
+        field_schema.update(to_json_schema(cls.to_schema()))
+
+    def __class_getitem__(
+        cls: Type[TSchemaModel],
+        params: Union[Type[Any], Tuple[Type[Any], ...]],
+    ) -> Type[TSchemaModel]:
+        """Parameterize the class's generic arguments with the specified types"""
+        if not hasattr(cls, "__parameters__"):
+            raise TypeError(
+                f"{cls.__name__} must inherit from typing.Generic before being parameterized"
+            )
+        # pylint: disable=no-member
+        __parameters__: Tuple[TypeVar, ...] = cls.__parameters__  # type: ignore
+
+        if not isinstance(params, tuple):
+            params = (params,)
+        if len(params) != len(__parameters__):
+            raise ValueError(
+                f"Expected {len(__parameters__)} generic arguments but found {len(params)}"
+            )
+        if (cls, params) in GENERIC_SCHEMA_CACHE:
+            return typing.cast(
+                Type[TSchemaModel], GENERIC_SCHEMA_CACHE[(cls, params)]
+            )
+
+        param_dict: Dict[TypeVar, Type[Any]] = dict(
+            zip(__parameters__, params)
+        )
+        extra: Dict[str, Any] = {"__annotations__": {}}
+        for field, (annot_info, field_info) in cls._collect_fields().items():
+            if isinstance(annot_info.arg, TypeVar):
+                if annot_info.arg in param_dict:
+                    raw_annot = annot_info.origin[param_dict[annot_info.arg]]  # type: ignore
+                    if annot_info.optional:
+                        raw_annot = Optional[raw_annot]
+                    extra["__annotations__"][field] = raw_annot
+                    extra[field] = copy.deepcopy(field_info)
+
+        parameterized_name = (
+            f"{cls.__name__}[{', '.join(p.__name__ for p in params)}]"
+        )
+        parameterized_cls = type(parameterized_name, (cls,), extra)
+        GENERIC_SCHEMA_CACHE[(cls, params)] = parameterized_cls
+        return parameterized_cls
+
 
 def _build_schema_index(
     indices: List[schema_components.Index], **multiindex_kwargs: Any
