@@ -1,4 +1,5 @@
 """Components used in pandera schemas."""
+from __future__ import annotations
 
 import warnings
 from copy import copy, deepcopy
@@ -9,13 +10,14 @@ import pandas as pd
 
 from . import check_utils, errors
 from . import strategies as st
-from .deprecations import deprecate_pandas_dtype
+from .dtypes import UniqueSettings
 from .error_handlers import SchemaErrorHandler
 from .schemas import (
     CheckList,
     DataFrameSchema,
     PandasDtypeInputTypes,
     SeriesSchemaBase,
+    StrictType,
 )
 
 
@@ -27,47 +29,42 @@ def _is_valid_multiindex_tuple_str(x: Tuple[Any, ...]) -> bool:
 class Column(SeriesSchemaBase):
     """Validate types and properties of DataFrame columns."""
 
-    @deprecate_pandas_dtype
     def __init__(
         self,
         dtype: PandasDtypeInputTypes = None,
         checks: CheckList = None,
         nullable: bool = False,
         unique: bool = False,
-        allow_duplicates: Optional[bool] = None,
+        report_duplicates: UniqueSettings = "all",
         coerce: bool = False,
         required: bool = True,
         name: Union[str, Tuple[str, ...], None] = None,
         regex: bool = False,
-        pandas_dtype: PandasDtypeInputTypes = None,
+        title: Optional[str] = None,
+        description: Optional[str] = None,
     ) -> None:
         """Create column validator object.
 
-        :param dtype: datatype of the column. A ``PandasDtype`` for
-            type-checking dataframe. If a string is specified, then assumes
+        :param dtype: datatype of the column. The datatype for type-checking
+            a dataframe. If a string is specified, then assumes
             one of the valid pandas string values:
             http://pandas.pydata.org/pandas-docs/stable/basics.html#dtypes
         :param checks: checks to verify validity of the column
         :param nullable: Whether or not column can contain null values.
-        :param unique: whether column values should be unique
-        :param allow_duplicates: Whether or not column can contain duplicate
-            values.
-
-            .. warning::
-
-                This option will be deprecated in 0.8.0. Use the ``unique``
-                argument instead.
-
+        :param unique: whether column values should be unique.
+        :param report_duplicates: how to report unique errors
+            - `exclude_first`: report all duplicates except first occurence
+            - `exclude_last`: report all duplicates except last occurence
+            - `all`: (default) report all duplicates
         :param coerce: If True, when schema.validate is called the column will
             be coerced into the specified dtype. This has no effect on columns
-            where ``pandas_dtype=None``.
+            where ``dtype=None``.
         :param required: Whether or not column is allowed to be missing
         :param name: column name in dataframe to validate.
         :param regex: whether the ``name`` attribute should be treated as a
             regex pattern to apply to multiple columns in a dataframe.
-        :param pandas_dtype: alias of ``dtype`` for backwards compatibility.
-
-            .. warning:: This option will be deprecated in 0.8.0
+        :param title: A human-readable label for the column.
+        :param description: An arbitrary textual description of the column.
 
         :raises SchemaInitError: if impossible to build schema from parameters
 
@@ -93,10 +90,11 @@ class Column(SeriesSchemaBase):
             checks,
             nullable,
             unique,
-            allow_duplicates,
+            report_duplicates,
             coerce,
             name,
-            pandas_dtype,
+            title,
+            description,
         )
         if (
             name is not None
@@ -133,6 +131,8 @@ class Column(SeriesSchemaBase):
             "required": self.required,
             "name": self._name,
             "regex": self._regex,
+            "title": self.title,
+            "description": self.description,
         }
 
     def set_name(self, name: str):
@@ -372,27 +372,16 @@ class Index(SeriesSchemaBase):
                 self, check_obj, "Attempting to validate mismatch index"
             )
 
-        series_cls = pd.Series
-        # NOTE: this is a hack to get koalas working, this needs a more
-        # principled implementation
-        if type(check_obj).__module__ == "databricks.koalas.frame":
-            # pylint: disable=import-outside-toplevel
-            import databricks.koalas as ks
-
-            series_cls = ks.Series
-
         if self.coerce:
             check_obj.index = self.coerce_dtype(check_obj.index)
             # handles case where pandas native string type is not supported
             # by index.
             obj_to_validate = self.dtype.coerce(
-                series_cls(
-                    check_obj.index.to_numpy(), name=check_obj.index.name
-                )
+                check_obj.index.to_series().reset_index(drop=True)
             )
         else:
-            obj_to_validate = series_cls(
-                check_obj.index.to_numpy(), name=check_obj.index.name
+            obj_to_validate = check_obj.index.to_series().reset_index(
+                drop=True
             )
 
         assert check_utils.is_field(
@@ -465,10 +454,11 @@ class MultiIndex(DataFrameSchema):
         self,
         indexes: List[Index],
         coerce: bool = False,
-        strict: bool = False,
-        name: str = None,
+        strict: StrictType = False,
+        name: Optional[str] = None,
         ordered: bool = True,
         unique: Optional[Union[str, List[str]]] = None,
+        report_duplicates: UniqueSettings = "all",
     ) -> None:
         """Create MultiIndex validator.
 
@@ -545,6 +535,7 @@ class MultiIndex(DataFrameSchema):
             name=name,
             ordered=ordered,
             unique=unique,
+            report_duplicates=report_duplicates,
         )
 
     @property
@@ -591,18 +582,30 @@ class MultiIndex(DataFrameSchema):
                 coerced_multi_index[index_level] = index_array
 
         if error_handler.collected_errors:
-            raise errors.SchemaErrors(error_handler.collected_errors, obj)
+            raise errors.SchemaErrors(
+                self, error_handler.collected_errors, obj
+            )
 
         multiindex_cls = pd.MultiIndex
-        # NOTE: this is a hack to support koalas
-        if type(obj).__module__.startswith("databricks.koalas"):
+        # NOTE: this is a hack to support pyspark.pandas
+        if type(obj).__module__.startswith("pyspark.pandas"):
             # pylint: disable=import-outside-toplevel
-            import databricks.koalas as ks
+            import pyspark.pandas as ps
 
-            multiindex_cls = ks.MultiIndex
+            multiindex_cls = ps.MultiIndex
         return multiindex_cls.from_arrays(
             [
+                # v.dtype may be different than 'object'.
+                # - Reuse the original index array to keep the specialized dtype:
+                #   v.to_numpy()  converts the array dtype to array of 'object' dtype.
+                #   Thus removing the specialized index dtype required to pass a schema's
+                #   index specialized dtype : eg: pandera.typing.Index(pandas.Int64Dtype)
+                # - For Pyspark only, use to_numpy(), with the effect of keeping the
+                #   bug open on this execution environment: At the time of writing, pyspark
+                #   v3.3.0 does not provide a working implementation of v.array
                 v.to_numpy()
+                if type(v).__module__.startswith("pyspark.pandas")
+                else v.array
                 for k, v in sorted(
                     coerced_multi_index.items(), key=lambda x: x[0]
                 )
@@ -679,8 +682,8 @@ class MultiIndex(DataFrameSchema):
             Emulate the behavior of pandas.MultiIndex.to_frame, but preserve
             duplicate index names if they exist.
             """
-            # NOTE: this is a hack to support koalas
-            if type(multiindex).__module__.startswith("databricks.koalas"):
+            # NOTE: this is a hack to support pyspark.pandas
+            if type(multiindex).__module__.startswith("pyspark.pandas"):
                 df = multiindex.to_frame()
             else:
                 df = pd.DataFrame(
@@ -724,7 +727,7 @@ class MultiIndex(DataFrameSchema):
                 schema_error_dict["error"] = error
                 schema_error_dicts.append(schema_error_dict)
 
-            raise errors.SchemaErrors(schema_error_dicts, check_obj)
+            raise errors.SchemaErrors(self, schema_error_dicts, check_obj)
 
         assert check_utils.is_table(validation_result)
         return check_obj
