@@ -13,13 +13,14 @@ from pathlib import Path
 from typing import (
     TYPE_CHECKING,
     Any,
-    Callable,
     Dict,
     List,
     Optional,
+    Type,
     TypeVar,
     Union,
     cast,
+    overload,
 )
 
 import numpy as np
@@ -28,8 +29,7 @@ import pandas as pd
 from . import check_utils, errors
 from . import strategies as st
 from .checks import Check
-from .deprecations import deprecate_pandas_dtype
-from .dtypes import DataType
+from .dtypes import DataType, UniqueSettings
 from .engines import pandas_engine
 from .error_formatters import (
     format_generic_error_message,
@@ -40,10 +40,20 @@ from .error_formatters import (
 from .error_handlers import SchemaErrorHandler
 from .hypotheses import Hypothesis
 
+try:
+    from typing import Literal
+except ImportError:
+    from typing_extensions import Literal  # type: ignore[misc]
+
+try:
+    from typing import Self  # type: ignore[attr-defined]
+except ImportError:
+    from typing_extensions import Self
+
+
 if TYPE_CHECKING:
     from pandera.schema_components import Column
 
-
 N_INDENT_SPACES = 4
 
 CheckList = Optional[
@@ -56,11 +66,14 @@ PandasDtypeInputTypes = Union[
     str,
     type,
     DataType,
-    pd.core.dtypes.base.ExtensionDtype,
+    Type,
+    pd.api.extensions.ExtensionDtype,
     np.dtype,
     None,
 ]
 
+StrictType = Union[bool, Literal["filter"]]
+
 TSeriesSchemaBase = TypeVar("TSeriesSchemaBase", bound="SeriesSchemaBase")
 
 
@@ -86,20 +99,21 @@ def _inferred_schema_guard(method):
 class DataFrameSchema:  # pylint: disable=too-many-public-methods
     """A light-weight pandas DataFrame validator."""
 
-    @deprecate_pandas_dtype
     def __init__(
         self,
-        columns: Optional[Dict[str, Column]] = None,
+        columns: Optional[Dict[Any, Column]] = None,
         checks: CheckList = None,
         index=None,
         dtype: PandasDtypeInputTypes = None,
-        transformer: Callable = None,
         coerce: bool = False,
-        strict: Union[bool, str] = False,
+        strict: StrictType = False,
         name: Optional[str] = None,
         ordered: bool = False,
-        pandas_dtype: PandasDtypeInputTypes = None,
         unique: Optional[Union[str, List[str]]] = None,
+        report_duplicates: UniqueSettings = "all",
+        unique_column_names: bool = False,
+        title: Optional[str] = None,
+        description: Optional[str] = None,
     ) -> None:
         """Initialize DataFrameSchema validator.
 
@@ -113,17 +127,9 @@ class DataFrameSchema:  # pylint: disable=too-many-public-methods
             types specified in any of the columns. If a string is specified,
             then assumes one of the valid pandas string values:
             http://pandas.pydata.org/pandas-docs/stable/basics.html#dtypes.
-        :param transformer: a callable with signature:
-            pandas.DataFrame -> pandas.DataFrame. If specified, calling
-            `validate` will verify properties of the columns and return the
-            transformed dataframe object.
-
-            .. warning:: This feature is deprecated and no longer has an effect
-                on validated dataframes.
-
         :param coerce: whether or not to coerce all of the columns on
             validation. This has no effect on columns where
-            ``pandas_dtype=None``
+            ``dtype=None``
         :param strict: ensure that all and only the columns defined in the
             schema are present in the dataframe. If set to 'filter',
             only the columns in the schema will be passed to the validated
@@ -131,15 +137,17 @@ class DataFrameSchema:  # pylint: disable=too-many-public-methods
             are not present in the dataframe, will throw an error.
         :param name: name of the schema.
         :param ordered: whether or not to validate the columns order.
-        :param pandas_dtype: alias of ``dtype`` for backwards compatibility.
-
-            .. warning:: This option will be deprecated in 0.8.0
-
         :param unique: a list of columns that should be jointly unique.
+        :param report_duplicates: how to report unique errors
+            - `exclude_first`: report all duplicates except first occurence
+            - `exclude_last`: report all duplicates except last occurence
+            - `all`: (default) report all duplicates
+
+        :param unique_column_names: whether or not column names must be unique.
+        :param title: A human-readable label for the schema.
+        :param description: An arbitrary textual description of the schema.
 
         :raises SchemaInitError: if impossible to build schema from parameters
-        :raises SchemaInitError: if ``dtype`` and ``pandas_dtype`` are both
-            supplied.
 
         :examples:
 
@@ -179,16 +187,6 @@ class DataFrameSchema:  # pylint: disable=too-many-public-methods
 
         self.columns: Dict[Any, Column] = {} if columns is None else columns
 
-        if transformer is not None:
-            warnings.warn(
-                "The `transformers` argument has been deprecated and will no "
-                "longer have any effect on validated dataframes. To achieve "
-                "the same goal, you can apply the function to the validated "
-                "data with `transformer(schema(df))` or "
-                "`schema(df).pipe(transformer)`",
-                DeprecationWarning,
-            )
-
         if strict not in (
             False,
             True,
@@ -201,12 +199,16 @@ class DataFrameSchema:  # pylint: disable=too-many-public-methods
 
         self.checks: CheckListProperty = checks
         self.index = index
-        self.strict: Union[bool, str] = strict
+        self.strict: StrictType = strict
         self.name: Optional[str] = name
-        self.dtype: PandasDtypeInputTypes = dtype or pandas_dtype  # type: ignore
+        self.dtype: PandasDtypeInputTypes = dtype  # type: ignore
         self._coerce = coerce
         self._ordered = ordered
         self._unique = unique
+        self._report_duplicates = report_duplicates
+        self._unique_column_names = unique_column_names
+        self._title = title
+        self._description = description
         self._validate_schema()
         self._set_column_names()
 
@@ -214,6 +216,13 @@ class DataFrameSchema:  # pylint: disable=too-many-public-methods
         # set to True in the case that a schema is created by infer_schema.
         self._IS_INFERRED = False
 
+        # This restriction can be removed once logical types are introduced:
+        # https://github.com/pandera-dev/pandera/issues/788
+        if not coerce and isinstance(self.dtype, pandas_engine.PydanticModel):
+            raise errors.SchemaInitError(
+                "Specifying a PydanticModel type requires coerce=True."
+            )
+
     @property
     def coerce(self) -> bool:
         """Whether to coerce series to specified type."""
@@ -244,6 +253,26 @@ class DataFrameSchema:  # pylint: disable=too-many-public-methods
         """Set ordered attribute"""
         self._ordered = value
 
+    @property
+    def unique_column_names(self):
+        """Whether multiple columns with the same name can be present."""
+        return self._unique_column_names
+
+    @unique_column_names.setter
+    def unique_column_names(self, value: bool) -> None:
+        """Set allow_duplicated_column_names attribute"""
+        self._unique_column_names = value
+
+    @property
+    def title(self):
+        """A human-readable label for the schema."""
+        return self._title
+
+    @property
+    def description(self):
+        """An arbitrary textual description of the schema."""
+        return self._description
+
     # the _is_inferred getter and setter methods are not public
     @property
     def _is_inferred(self) -> bool:
@@ -353,7 +382,7 @@ class DataFrameSchema:  # pylint: disable=too-many-public-methods
                 obj,
                 (
                     f"Error while coercing '{self.name}' to type "
-                    f"{self.dtype}: {exc}"
+                    f"{self.dtype}: {exc}\n{exc.failure_cases}"
                 ),
                 failure_cases=exc.failure_cases,
                 check=f"coerce_dtype('{self.dtype}')",
@@ -408,7 +437,9 @@ class DataFrameSchema:  # pylint: disable=too-many-public-methods
                 obj.index = coerced_index
 
         if error_handler.collected_errors:
-            raise errors.SchemaErrors(error_handler.collected_errors, obj)
+            raise errors.SchemaErrors(
+                self, error_handler.collected_errors, obj
+            )
 
         return obj
 
@@ -563,11 +594,13 @@ class DataFrameSchema:  # pylint: disable=too-many-public-methods
             else:
                 columns = check_obj.columns
 
+            filter_out_columns = []
+
             for column in columns:
                 is_schema_col = column in expanded_column_names
                 if (self.strict is True) and not is_schema_col:
                     msg = (
-                        f"column '{column}' not in DataFrameSchema"
+                        f"column '{column}' not in {self.__class__.__name__}"
                         f" {self.columns}"
                     )
                     error_handler.collect_error(
@@ -581,7 +614,7 @@ class DataFrameSchema:  # pylint: disable=too-many-public-methods
                         ),
                     )
                 if self.strict == "filter" and not is_schema_col:
-                    check_obj.drop(labels=[column], inplace=True, axis=1)
+                    filter_out_columns.append(column)
                 if self.ordered and is_schema_col:
                     try:
                         next_ordered_col = next(sorted_column_names)
@@ -599,6 +632,27 @@ class DataFrameSchema:  # pylint: disable=too-many-public-methods
                             ),
                         )
 
+        if self.strict == "filter":
+            check_obj.drop(labels=filter_out_columns, inplace=True, axis=1)
+
+        if self._unique_column_names:
+            failed = check_obj.columns[check_obj.columns.duplicated()]
+            if failed.any():
+                msg = (
+                    "dataframe contains multiple columns with label(s): "
+                    f"{failed.tolist()}"
+                )
+                error_handler.collect_error(
+                    "duplicate_dataframe_column_labels",
+                    errors.SchemaError(
+                        self,
+                        check_obj,
+                        msg,
+                        failure_cases=scalar_failure_case(failed),
+                        check="dataframe_column_labels_unique",
+                    ),
+                )
+
         # check for columns that are not in the dataframe and collect columns
         # that are not in the dataframe that should be excluded for lazy
         # validation
@@ -649,9 +703,10 @@ class DataFrameSchema:  # pylint: disable=too-many-public-methods
             if (
                 col.required or col_name in check_obj
             ) and col_name not in lazy_exclude_columns:
+                col = copy.deepcopy(col)
+                col._coerce = False  # type: ignore
                 if self.dtype is not None:
                     # override column dtype with dataframe dtype
-                    col = copy.deepcopy(col)
                     col.dtype = self.dtype
                 schema_components.append(col)
 
@@ -693,24 +748,30 @@ class DataFrameSchema:  # pylint: disable=too-many-public-methods
                 error_handler.collect_error("dataframe_check", err)
 
         if self.unique:
+            keep_setting = convert_uniquesettings(self._report_duplicates)
+            # NOTE: fix this pylint error
+            # pylint: disable=not-an-iterable
             temp_unique: List[List] = (
                 [self.unique]
                 if all(isinstance(x, str) for x in self.unique)
                 else self.unique
             )
             for lst in temp_unique:
-                duplicates = df_to_validate.duplicated(subset=lst, keep=False)
+                duplicates = df_to_validate.duplicated(
+                    subset=lst, keep=keep_setting
+                )
                 if duplicates.any():
-                    # NOTE: this is a hack to support koalas, need to figure
-                    # out a workaround to error: "Cannot combine the series or
-                    # dataframe because it comes from a different dataframe."
+                    # NOTE: this is a hack to support pyspark.pandas, need to
+                    # figure out a workaround to error: "Cannot combine the
+                    # series or dataframe because it comes from a different
+                    # dataframe."
                     if type(duplicates).__module__.startswith(
-                        "databricks.koalas"
+                        "pyspark.pandas"
                     ):
                         # pylint: disable=import-outside-toplevel
-                        import databricks.koalas as ks
+                        import pyspark.pandas as ps
 
-                        with ks.option_context(
+                        with ps.option_context(
                             "compute.ops_on_diff_frames", True
                         ):
                             failure_cases = df_to_validate.loc[duplicates, lst]
@@ -731,7 +792,7 @@ class DataFrameSchema:  # pylint: disable=too-many-public-methods
 
         if lazy and error_handler.collected_errors:
             raise errors.SchemaErrors(
-                error_handler.collected_errors, check_obj
+                self, error_handler.collected_errors, check_obj
             )
 
         assert all(check_results), "all check results must be True."
@@ -777,10 +838,11 @@ class DataFrameSchema:  # pylint: disable=too-many-public-methods
             f"checks={self.checks}, "
             f"index={self.index.__repr__()}, "
             f"coerce={self.coerce}, "
-            f"dtype={self._dtype},"
-            f"strict={self.strict},"
-            f"name={self.name},"
-            f"ordered={self.ordered}"
+            f"dtype={self._dtype}, "
+            f"strict={self.strict}, "
+            f"name={self.name}, "
+            f"ordered={self.ordered}, "
+            f"unique_column_names={self.unique_column_names}"
             ")>"
         )
 
@@ -828,7 +890,8 @@ class DataFrameSchema:  # pylint: disable=too-many-public-methods
             f"{indent}index={index},\n"
             f"{indent}strict={self.strict}\n"
             f"{indent}name={self.name},\n"
-            f"{indent}ordered={self.ordered}\n"
+            f"{indent}ordered={self.ordered},\n"
+            f"{indent}unique_column_names={self.unique_column_names}\n"
             ")>"
         )
 
@@ -884,9 +947,7 @@ class DataFrameSchema:  # pylint: disable=too-many-public-methods
             ).example()
 
     @_inferred_schema_guard
-    def add_columns(
-        self, extra_schema_cols: Dict[str, Any]
-    ) -> "DataFrameSchema":
+    def add_columns(self, extra_schema_cols: Dict[str, Any]) -> Self:
         """Create a copy of the :class:`DataFrameSchema` with extra columns.
 
         :param extra_schema_cols: Additional columns of the format
@@ -922,7 +983,8 @@ class DataFrameSchema:  # pylint: disable=too-many-public-methods
             index=None,
             strict=False
             name=None,
-            ordered=False
+            ordered=False,
+            unique_column_names=False
         )>
 
         .. seealso:: :func:`remove_columns`
@@ -931,12 +993,12 @@ class DataFrameSchema:  # pylint: disable=too-many-public-methods
         schema_copy = copy.deepcopy(self)
         schema_copy.columns = {
             **schema_copy.columns,
-            **DataFrameSchema(extra_schema_cols).columns,
+            **self.__class__(extra_schema_cols).columns,
         }
         return schema_copy
 
     @_inferred_schema_guard
-    def remove_columns(self, cols_to_remove: List[str]) -> "DataFrameSchema":
+    def remove_columns(self, cols_to_remove: List[str]) -> Self:
         """Removes columns from a :class:`DataFrameSchema` and returns a new
         copy.
 
@@ -972,7 +1034,8 @@ class DataFrameSchema:  # pylint: disable=too-many-public-methods
             index=None,
             strict=False
             name=None,
-            ordered=False
+            ordered=False,
+            unique_column_names=False
         )>
 
         .. seealso:: :func:`add_columns`
@@ -995,7 +1058,7 @@ class DataFrameSchema:  # pylint: disable=too-many-public-methods
         return schema_copy
 
     @_inferred_schema_guard
-    def update_column(self, column_name: str, **kwargs) -> "DataFrameSchema":
+    def update_column(self, column_name: str, **kwargs) -> Self:
         """Create copy of a :class:`DataFrameSchema` with updated column
         properties.
 
@@ -1033,7 +1096,8 @@ class DataFrameSchema:  # pylint: disable=too-many-public-methods
             index=None,
             strict=False
             name=None,
-            ordered=False
+            ordered=False,
+            unique_column_names=False
         )>
 
         .. seealso:: :func:`rename_columns`
@@ -1053,9 +1117,7 @@ class DataFrameSchema:  # pylint: disable=too-many-public-methods
         schema_copy.columns.update({column_name: new_column})
         return schema_copy
 
-    def update_columns(
-        self, update_dict: Dict[str, Dict[str, Any]]
-    ) -> "DataFrameSchema":
+    def update_columns(self, update_dict: Dict[str, Dict[str, Any]]) -> Self:
         """
         Create copy of a :class:`DataFrameSchema` with updated column
         properties.
@@ -1093,12 +1155,10 @@ class DataFrameSchema:  # pylint: disable=too-many-public-methods
             index=None,
             strict=False
             name=None,
-            ordered=False
+            ordered=False,
+            unique_column_names=False
         )>
 
-        .. note:: This is the successor to the ``update_column`` method, which
-            will be deprecated.
-
         """
 
         new_schema = copy.deepcopy(self)
@@ -1137,7 +1197,7 @@ class DataFrameSchema:  # pylint: disable=too-many-public-methods
 
         return new_schema
 
-    def rename_columns(self, rename_dict: Dict[str, str]) -> "DataFrameSchema":
+    def rename_columns(self, rename_dict: Dict[str, str]) -> Self:
         """Rename columns using a dictionary of key-value pairs.
 
         :param rename_dict: dictionary of 'old_name': 'new_name' key-value
@@ -1175,7 +1235,8 @@ class DataFrameSchema:  # pylint: disable=too-many-public-methods
             index=None,
             strict=False
             name=None,
-            ordered=False
+            ordered=False,
+            unique_column_names=False
         )>
 
         .. seealso:: :func:`update_column`
@@ -1192,6 +1253,9 @@ class DataFrameSchema:  # pylint: disable=too-many-public-methods
                 f"Keys {not_in_cols} not found in schema columns!"
             )
 
+        # remove any mapping to itself as this is a no-op
+        rename_dict = {k: v for k, v in rename_dict.items() if k != v}
+
         # ensure all new keys are not present in the current column names
         already_in_columns: List[str] = [
             x for x in rename_dict.values() if x in new_schema.columns.keys()
@@ -1217,7 +1281,7 @@ class DataFrameSchema:  # pylint: disable=too-many-public-methods
 
         return new_schema
 
-    def select_columns(self, columns: List[Any]) -> "DataFrameSchema":
+    def select_columns(self, columns: List[Any]) -> Self:
         """Select subset of columns in the schema.
 
         *New in version 0.4.5*
@@ -1250,7 +1314,8 @@ class DataFrameSchema:  # pylint: disable=too-many-public-methods
             index=None,
             strict=False
             name=None,
-            ordered=False
+            ordered=False,
+            unique_column_names=False
         )>
 
         .. note:: If an index is present in the schema, it will also be
@@ -1301,20 +1366,67 @@ class DataFrameSchema:  # pylint: disable=too-many-public-methods
 
         return pandera.io.from_yaml(yaml_schema)
 
-    def to_yaml(self, stream: Optional[os.PathLike] = None):
+    @overload
+    def to_yaml(self, stream: None = None) -> str:  # pragma: no cover
+        ...
+
+    @overload
+    def to_yaml(self, stream: os.PathLike) -> None:  # pragma: no cover
+        ...
+
+    def to_yaml(self, stream: Optional[os.PathLike] = None) -> Optional[str]:
         """Write DataFrameSchema to yaml file.
 
-        :param stream: file stream to write to. If None, dumps to string.
+        :param stream: file path or stream to write to. If None, dumps
+            to string.
         :returns: yaml string if stream is None, otherwise returns None.
         """
         # pylint: disable=import-outside-toplevel,cyclic-import
         import pandera.io
 
-        return pandera.io.to_yaml(self, stream=stream)
+        return pandera.io.to_yaml(self, stream)
+
+    @classmethod
+    def from_json(cls, source) -> "DataFrameSchema":
+        """Create DataFrameSchema from json file.
+
+        :param source: str, Path to json schema, or serialized yaml
+            string.
+        :returns: dataframe schema.
+        """
+        # pylint: disable=import-outside-toplevel,cyclic-import
+        import pandera.io
+
+        return pandera.io.from_json(source)
+
+    @overload
+    def to_json(
+        self, target: None = None, **kwargs
+    ) -> str:  # pragma: no cover
+        ...
+
+    @overload
+    def to_json(
+        self, target: os.PathLike, **kwargs
+    ) -> None:  # pragma: no cover
+        ...
+
+    def to_json(
+        self, target: Optional[os.PathLike] = None, **kwargs
+    ) -> Optional[str]:
+        """Write DataFrameSchema to json file.
+
+        :param target: file target to write to. If None, dumps to string.
+        :returns: json string if target is None, otherwise returns None.
+        """
+        # pylint: disable=import-outside-toplevel,cyclic-import
+        import pandera.io
+
+        return pandera.io.to_json(self, target, **kwargs)
 
     def set_index(
         self, keys: List[str], drop: bool = True, append: bool = False
-    ) -> "DataFrameSchema":
+    ) -> Self:
         """
         A method for setting the :class:`Index` of a :class:`DataFrameSchema`,
         via an existing :class:`Column` or list of columns.
@@ -1350,7 +1462,8 @@ class DataFrameSchema:  # pylint: disable=too-many-public-methods
             index=<Schema Index(name=category, type=DataType(str))>,
             strict=False
             name=None,
-            ordered=False
+            ordered=False,
+            unique_column_names=False
         )>
 
         If you have an existing index in your schema, and you would like to
@@ -1385,7 +1498,8 @@ class DataFrameSchema:  # pylint: disable=too-many-public-methods
             )>,
             strict=False
             name=None,
-            ordered=False
+            ordered=False,
+            unique_column_names=False
         )>
 
         .. seealso:: :func:`reset_index`
@@ -1415,7 +1529,7 @@ class DataFrameSchema:  # pylint: disable=too-many-public-methods
             []
             if new_schema.index is None or not append
             else list(new_schema.index.indexes)
-            if check_utils.is_multiindex(new_schema.index) and append
+            if isinstance(new_schema.index, MultiIndex) and append
             else [new_schema.index]
         )
 
@@ -1441,14 +1555,12 @@ class DataFrameSchema:  # pylint: disable=too-many-public-methods
 
         return new_schema
 
-    def reset_index(
-        self, level: List[str] = None, drop: bool = False
-    ) -> "DataFrameSchema":
+    def reset_index(self, level: List[str] = None, drop: bool = False) -> Self:
         """
         A method for resetting the :class:`Index` of a :class:`DataFrameSchema`
 
         :param level: list of labels
-        :param drop: bool, default True
+        :param drop: bool, default False
         :return: a new :class:`DataFrameSchema` with specified column(s) in the
             index.
         :raises: :class:`~pandera.errors.SchemaInitError` if no index set in
@@ -1481,7 +1593,8 @@ class DataFrameSchema:  # pylint: disable=too-many-public-methods
             index=None,
             strict=False
             name=None,
-            ordered=False
+            ordered=False,
+            unique_column_names=False
         )>
 
         This reclassifies an index (or indices) as a column (or columns).
@@ -1510,7 +1623,8 @@ class DataFrameSchema:  # pylint: disable=too-many-public-methods
             index=<Schema Index(name=unique_id2, type=DataType(str))>,
             strict=False
             name=None,
-            ordered=False
+            ordered=False,
+            unique_column_names=False
         )>
 
         .. seealso:: :func:`set_index`
@@ -1519,6 +1633,10 @@ class DataFrameSchema:  # pylint: disable=too-many-public-methods
         # pylint: disable=import-outside-toplevel,cyclic-import
         from pandera.schema_components import Column, Index, MultiIndex
 
+        # explcit check for an empty list
+        if level == []:
+            return self
+
         new_schema = copy.deepcopy(self)
 
         if new_schema.index is None:
@@ -1528,7 +1646,7 @@ class DataFrameSchema:  # pylint: disable=too-many-public-methods
 
         # ensure no duplicates
         level_temp: Union[List[Any], List[str]] = (
-            list(set(level)) if level is not None else []
+            new_schema.index.names if level is None else list(set(level))
         )
 
         # ensure all specified keys are present in the index
@@ -1609,17 +1727,17 @@ class DataFrameSchema:  # pylint: disable=too-many-public-methods
 class SeriesSchemaBase:
     """Base series validator object."""
 
-    @deprecate_pandas_dtype
     def __init__(
         self,
         dtype: PandasDtypeInputTypes = None,
         checks: CheckList = None,
         nullable: bool = False,
         unique: bool = False,
-        allow_duplicates: Optional[bool] = None,
+        report_duplicates: UniqueSettings = "all",
         coerce: bool = False,
         name: Any = None,
-        pandas_dtype: PandasDtypeInputTypes = None,
+        title: Optional[str] = None,
+        description: Optional[str] = None,
     ) -> None:
         """Initialize series schema base object.
 
@@ -1633,24 +1751,17 @@ class SeriesSchemaBase:
             in the column. Otherwise, the input is assumed to be a
             pandas.Series object.
         :param nullable: Whether or not column can contain null values.
-        :param unique: Whether or not column can contain duplicate
-            values.
-        :param allow_duplicates: Whether or not column can contain duplicate
-            values.
-
-        .. warning::
-
-            This option will be deprecated in 0.8.0. Use the ``unique``
-            argument instead.
-
+        :param unique: whether column values should be unique.
+        :param report_duplicates: how to report unique errors
+            - `exclude_first`: report all duplicates except first occurence
+            - `exclude_last`: report all duplicates except last occurence
+            - `all`: (default) report all duplicates
         :param coerce: If True, when schema.validate is called the column will
             be coerced into the specified dtype. This has no effect on columns
             where ``dtype=None``.
         :param name: column name in dataframe to validate.
-        :param pandas_dtype: alias of ``dtype`` for backwards compatibility.
-
-            .. warning:: This option will be deprecated in 0.8.0
-
+        :param title: A human-readable label for the series.
+        :param description: An arbitrary textual description of the series.
         :type nullable: bool
         """
         if checks is None:
@@ -1658,22 +1769,15 @@ class SeriesSchemaBase:
         if isinstance(checks, (Check, Hypothesis)):
             checks = [checks]
 
-        if allow_duplicates is not None:
-            warnings.warn(
-                "The `allow_duplicates` will be deprecated in "
-                "favor of the `unique` keyword. The value of "
-                "`unique` will be set to the opposite of "
-                "the `allow_duplicates` keyword.",
-                DeprecationWarning,
-            )
-            unique = not allow_duplicates
-
-        self.dtype = dtype or pandas_dtype  # type: ignore
+        self.dtype = dtype  # type: ignore
         self._nullable = nullable
         self._coerce = coerce
         self._checks = checks
         self._name = name
         self._unique = unique
+        self._report_duplicates = report_duplicates
+        self._title = title
+        self._description = description
 
         for check in self.checks:
             if check.groupby is not None and not self._allow_groupby:
@@ -1688,6 +1792,12 @@ class SeriesSchemaBase:
         # set to True in the case that a schema is created by infer_schema.
         self._IS_INFERRED = False
 
+        if isinstance(self.dtype, pandas_engine.PydanticModel):
+            raise errors.SchemaInitError(
+                "PydanticModel dtype can only be specified as a "
+                "DataFrameSchema dtype."
+            )
+
     # the _is_inferred getter and setter methods are not public
     @property
     def _is_inferred(self):
@@ -1732,16 +1842,6 @@ class SeriesSchemaBase:
         """Set unique attribute"""
         self._unique = value
 
-    @property
-    def allow_duplicates(self) -> bool:
-        """Whether to allow duplicate values."""
-        return not self._unique
-
-    @allow_duplicates.setter
-    def allow_duplicates(self, value: bool) -> None:
-        """Set allow_duplicates attribute."""
-        self._unique = not value
-
     @property
     def coerce(self) -> bool:
         """Whether to coerce series to specified type."""
@@ -1757,6 +1857,16 @@ class SeriesSchemaBase:
         """Get SeriesSchema name."""
         return self._name
 
+    @property
+    def title(self):
+        """A human-readable label for the series."""
+        return self._title
+
+    @property
+    def description(self):
+        """An arbitrary textual description of the series."""
+        return self._description
+
     @property
     def dtype(
         self,
@@ -1898,17 +2008,21 @@ class SeriesSchemaBase:
 
         # Check if the series contains duplicate values
         if self._unique:
-            if type(series).__module__.startswith("databricks.koalas"):
+            keep_argument = convert_uniquesettings(self._report_duplicates)
+
+            if type(series).__module__.startswith("pyspark.pandas"):
                 duplicates = (
-                    series.to_frame().duplicated().reindex(series.index)
+                    series.to_frame()
+                    .duplicated(keep=keep_argument)
+                    .reindex(series.index)
                 )
                 # pylint: disable=import-outside-toplevel
-                import databricks.koalas as ks
+                import pyspark.pandas as ps
 
-                with ks.option_context("compute.ops_on_diff_frames", True):
+                with ps.option_context("compute.ops_on_diff_frames", True):
                     failed = series[duplicates]
             else:
-                duplicates = series.duplicated()
+                duplicates = series.duplicated(keep=keep_argument)
                 failed = series[duplicates]
 
             if duplicates.any():
@@ -1927,23 +2041,43 @@ class SeriesSchemaBase:
                     ),
                 )
 
-        if self._dtype is not None and (
-            not self._dtype.check(pandas_engine.Engine.dtype(series.dtype))
-        ):
-            msg = (
-                f"expected series '{series.name}' to have type {self._dtype}, "
-                + f"got {series.dtype}"
-            )
-            error_handler.collect_error(
-                "wrong_dtype",
-                errors.SchemaError(
-                    self,
-                    check_obj,
-                    msg,
-                    failure_cases=scalar_failure_case(str(series.dtype)),
-                    check=f"dtype('{self.dtype}')",
-                ),
+        if self._dtype is not None:
+            failure_cases = None
+
+            check_output = self._dtype.check(
+                pandas_engine.Engine.dtype(series.dtype), series
             )
+            if check_output is False:
+                failure_cases = scalar_failure_case(str(series.dtype))
+                msg = (
+                    f"expected series '{series.name}' to have type {self._dtype}, "
+                    + f"got {series.dtype}"
+                )
+            elif not isinstance(check_output, bool):
+                _, failure_cases = check_utils.prepare_series_check_output(
+                    series,
+                    pd.Series(list(check_output))
+                    if not isinstance(check_output, pd.Series)
+                    else check_output,
+                )
+                failure_cases = reshape_failure_cases(failure_cases)
+                msg = (
+                    f"expected series '{series.name}' to have type {self._dtype}:\n"
+                    f"failure cases:\n{failure_cases}"
+                )
+
+            if failure_cases is not None and not failure_cases.empty:
+
+                error_handler.collect_error(
+                    "wrong_dtype",
+                    errors.SchemaError(
+                        self,
+                        check_obj,
+                        msg,
+                        failure_cases=failure_cases,
+                        check=f"dtype('{self.dtype}')",
+                    ),
+                )
 
         check_results = []
         if check_utils.is_field(check_obj):
@@ -1984,7 +2118,7 @@ class SeriesSchemaBase:
 
         if lazy and error_handler.collected_errors:
             raise errors.SchemaErrors(
-                error_handler.collected_errors, check_obj
+                self, error_handler.collected_errors, check_obj
             )
 
         assert all(check_results)
@@ -2064,7 +2198,6 @@ class SeriesSchemaBase:
 class SeriesSchema(SeriesSchemaBase):
     """Series validator."""
 
-    @deprecate_pandas_dtype
     def __init__(
         self,
         dtype: PandasDtypeInputTypes = None,
@@ -2072,10 +2205,11 @@ class SeriesSchema(SeriesSchemaBase):
         index=None,
         nullable: bool = False,
         unique: bool = False,
-        allow_duplicates: Optional[bool] = None,
+        report_duplicates: UniqueSettings = "all",
         coerce: bool = False,
         name: str = None,
-        pandas_dtype: PandasDtypeInputTypes = None,
+        title: Optional[str] = None,
+        description: Optional[str] = None,
     ) -> None:
         """Initialize series schema base object.
 
@@ -2090,23 +2224,17 @@ class SeriesSchema(SeriesSchemaBase):
             pandas.Series object.
         :param index: specify the datatypes and properties of the index.
         :param nullable: Whether or not column can contain null values.
-        :param unique: Whether or not column can contain duplicate
-            values.
-        :param allow_duplicates: Whether or not column can contain duplicate
-            values.
-
-        .. warning::
-
-            This option will be deprecated in 0.8.0. Use the ``unique``
-            argument instead.
-
+        :param unique: whether column values should be unique.
+        :param report_duplicates: how to report unique errors
+            - `exclude_first`: report all duplicates except first occurence
+            - `exclude_last`: report all duplicates except last occurence
+            - `all`: (default) report all duplicates
         :param coerce: If True, when schema.validate is called the column will
             be coerced into the specified dtype. This has no effect on columns
-            where ``pandas_dtype=None``.
+            where ``dtype=None``.
         :param name: series name.
-        :param pandas_dtype: alias of ``dtype`` for backwards compatibility.
-
-            .. warning:: This option will be deprecated in 0.8.0
+        :param title: A human-readable label for the series.
+        :param description: An arbitrary textual description of the series.
 
         """
         super().__init__(
@@ -2114,10 +2242,11 @@ class SeriesSchema(SeriesSchemaBase):
             checks,
             nullable,
             unique,
-            allow_duplicates,
+            report_duplicates,
             coerce,
             name,
-            pandas_dtype,
+            title,
+            description,
         )
         self.index = index
 
@@ -2266,7 +2395,7 @@ class SeriesSchema(SeriesSchemaBase):
 
         if error_handler.collected_errors:
             raise errors.SchemaErrors(
-                error_handler.collected_errors, check_obj
+                self, error_handler.collected_errors, check_obj
             )
 
         return check_obj
@@ -2360,3 +2489,22 @@ def _handle_check_results(
             check_output=check_result.check_output,
         )
     return check_result.check_passed
+
+
+def convert_uniquesettings(unique: UniqueSettings) -> Union[bool, str]:
+    """
+    Converts UniqueSettings object to string that can be passed onto pandas .duplicated() call
+    """
+    # Default `keep` argument for pandas .duplicated() function
+    keep_argument: Union[bool, str]
+    if unique == "exclude_first":
+        keep_argument = "first"
+    elif unique == "exclude_last":
+        keep_argument = "last"
+    elif unique == "all":
+        keep_argument = False
+    else:
+        raise ValueError(
+            str(unique) + " is not a recognized report_duplicates value"
+        )
+    return keep_argument
