@@ -54,7 +54,7 @@ except ImportError:  # pragma: no cover
     class SearchStrategy:  # type: ignore
         """placeholder type."""
 
-    def composite(fn):
+    def composite(fn):  # type: ignore
         """placeholder composite strategy."""
         return fn
 
@@ -74,6 +74,8 @@ def _mask(
 ) -> Union[pd.Series, pd.Index]:
     if pd.api.types.is_timedelta64_dtype(val):
         return val.mask(null_mask, pd.NaT)
+    elif val.dtype == pd.StringDtype():
+        return val.mask(null_mask, pd.NA)
     return val.mask(null_mask)
 
 
@@ -211,8 +213,10 @@ def register_check_strategy(strategy_fn: StrategyFn):
 # pylint: disable=line-too-long
 # Values taken from
 # https://hypothesis.readthedocs.io/en/latest/_modules/hypothesis/extra/numpy.html#from_dtype  # noqa
-MIN_DT_VALUE = -(2 ** 63)
-MAX_DT_VALUE = 2 ** 63 - 1
+# NOTE: We're reducing the range here by an order of magnitude to avoid overflows
+# when synthesizing timezone-aware timestamps.
+MIN_DT_VALUE = -(2**62) + 1
+MAX_DT_VALUE = 2**62 - 1
 
 
 def _is_datetime_tz(pandera_dtype: DataType) -> bool:
@@ -223,7 +227,6 @@ def _is_datetime_tz(pandera_dtype: DataType) -> bool:
 def _datetime_strategy(
     dtype: Union[np.dtype, pd.DatetimeTZDtype], strategy
 ) -> SearchStrategy:
-
     if isinstance(dtype, pd.DatetimeTZDtype):
 
         def _to_datetime(value) -> pd.DatetimeTZDtype:
@@ -375,7 +378,7 @@ def pandas_dtype_strategy(
         )
 
     np_dtype = to_numpy_dtype(pandera_dtype)
-    if strategy:
+    if strategy is not None:
         if _is_datetime_tz(pandera_dtype):
             return _datetime_strategy(pandera_dtype.type, strategy)  # type: ignore
         return strategy.map(np_dtype.type)
@@ -821,7 +824,7 @@ def series_strategy(
             index=pdst.range_indexes(
                 min_size=0 if size is None else size, max_size=size
             ),
-            unique=unique,
+            unique=bool(unique),
         )
         .filter(lambda x: x.shape[0] > 0)
         .map(lambda x: x.rename(name))
@@ -911,7 +914,7 @@ def index_strategy(
         dtype=to_numpy_dtype(pandera_dtype),
         min_size=0 if size is None else size,
         max_size=size,
-        unique=unique,
+        unique=bool(unique),
     ).map(lambda x: x.astype(pandera_dtype.type))
 
     # this is a hack to convert np.str_ data values into native python str.
@@ -1100,14 +1103,23 @@ def dataframe_strategy(
         )
 
         # this is a hack to convert np.str_ data values into native python str.
+        string_columns = []
         for col_name, col_dtype in col_dtypes.items():
             if col_dtype in {"object", "str"} or col_dtype.startswith(
                 "string"
             ):
-                # pylint: disable=cell-var-from-loop,undefined-loop-variable
-                strategy = strategy.map(
-                    lambda df: df.assign(**{col_name: df[col_name].map(str)})
+                string_columns.append(col_name)
+
+        if string_columns:
+            # pylint: disable=cell-var-from-loop,undefined-loop-variable
+            strategy = strategy.map(
+                lambda df: df.assign(
+                    **{
+                        col_name: df[col_name].map(str)
+                        for col_name in string_columns
+                    }
                 )
+            )
 
         strategy = strategy.map(
             lambda df: df if df.empty else df.astype(col_dtypes)
