@@ -4,7 +4,9 @@ For backwards compatibility, pandas types are exposed to the top-level scope of
 the typing module.
 """
 
-from . import dask, koalas, modin
+from typing import Set, Type
+
+from . import dask, fastapi, geopandas, modin, pyspark
 from .common import (
     BOOL,
     INT8,
@@ -19,7 +21,9 @@ from .common import (
     AnnotationInfo,
     Bool,
     Category,
+    Date,
     DateTime,
+    Decimal,
     Float,
     Float16,
     Float32,
@@ -39,9 +43,9 @@ from .common import (
 )
 from .pandas import DataFrame, Index, Series
 
-DATAFRAME_TYPES = {DataFrame}
-SERIES_TYPES = {Series}
-INDEX_TYPES = {Index}
+DATAFRAME_TYPES: Set[Type] = {DataFrame}
+SERIES_TYPES: Set[Type] = {Series}
+INDEX_TYPES: Set[Type] = {Index}
 
 if dask.DASK_INSTALLED:
     DATAFRAME_TYPES.update({dask.DataFrame})
@@ -53,10 +57,15 @@ if modin.MODIN_INSTALLED:
     SERIES_TYPES.update({modin.Series})
     INDEX_TYPES.update({modin.Index})
 
-if koalas.KOALAS_INSTALLED:
-    DATAFRAME_TYPES.update({koalas.DataFrame})
-    SERIES_TYPES.update({koalas.Series})
-    INDEX_TYPES.update({koalas.Index})
+if pyspark.PYSPARK_INSTALLED:
+    DATAFRAME_TYPES.update({pyspark.DataFrame})
+    SERIES_TYPES.update({pyspark.Series})
+    INDEX_TYPES.update({pyspark.Index})  # type: ignore [arg-type]
+
+
+if geopandas.GEOPANDAS_INSTALLED:
+    DATAFRAME_TYPES.update({geopandas.GeoDataFrame})
+    SERIES_TYPES.update({geopandas.GeoSeries})
 
 
 __all__ = [
