@@ -2,10 +2,13 @@
 
 from typing import TYPE_CHECKING, Generic, TypeVar
 
+from packaging import version
+
 from .common import DataFrameBase, IndexBase, SeriesBase
 from .pandas import GenericDtype, Schema
 
 try:
+    import modin
     import modin.pandas as mpd
 
     MODIN_INSTALLED = True
@@ -13,6 +16,11 @@ except ImportError:
     MODIN_INSTALLED = False
 
 
+def modin_version():
+    """Return the modin version."""
+    return version.parse(modin.__version__)
+
+
 # pylint:disable=invalid-name
 if TYPE_CHECKING:
     T = TypeVar("T")  # pragma: no cover
